@@ -17,8 +17,9 @@ define('io.ox/calendar/actions', [
     'io.ox/calendar/api',
     'io.ox/calendar/util',
     'io.ox/core/extPatterns/actions',
+    'io.ox/core/print',
     'gettext!io.ox/calendar'
-], function (ext, links, api, util, actions, gt) {
+], function (ext, links, api, util, actions, print, gt) {
 
     'use strict';
 
@@ -103,7 +104,7 @@ define('io.ox/calendar/actions', [
                     m.getApp().launch().done(function () {
                         this.create(coreSettings.get('folder/contacts'), { distribution_list: distlist });
                         // trigger an empty remove just to get rid of unnecessary values in contacts
-                        // if (!_.isEmpty(distlist)) this.view.baton.member.trigger('remove', {}, this.view.baton.member);
+                        if (!_.isEmpty(distlist)) this.view.baton.member.trigger('remove', {}, this.view.baton.member);
                     });
                 });
             });
@@ -177,20 +178,31 @@ define('io.ox/calendar/actions', [
             // incomplete
             if (app.id && !app.users) {
                 return api.get(app).then(cont);
-            } else {
-                return cont(app);
             }
+            return cont(app);
         },
         action: function (baton) {
             // load & call
-            ox.load(['io.ox/calendar/actions/acceptdeny']).done(function (acceptdeny) {
-                acceptdeny(baton.data);
+            ox.load(['io.ox/calendar/actions/acceptdeny']).done(function (action) {
+                action(baton.data);
+            });
+        }
+    });
+
+    new Action('io.ox/calendar/detail/actions/follow-up', {
+        requires: function (e) {
+            return e.collection.has('create', 'read');
+        },
+        action: function (baton) {
+            // load & call
+            ox.load(['io.ox/calendar/actions/follow-up']).done(function (action) {
+                action(baton.data);
             });
         }
     });
 
     new Action('io.ox/calendar/detail/actions/print-appointment', {
-        capabilities: 'printing',
+        capabilities: 'calendar-printing',
         requires: function (e) {
             return e.collection.has('some', 'read') && _.device('!smartphone');
         },
@@ -209,48 +221,38 @@ define('io.ox/calendar/actions', [
                         .show()
                         .done(function (action) {
                             if (action === 'detailed') {
-                                ox.load(['io.ox/core/print']).done(function (print) {
-                                    print.request('io.ox/calendar/print', list);
-                                });
-                            }
-                            if (action === 'compact') {
-                                ox.load(['io.ox/core/print']).done(function (print) {
-                                    print.request('io.ox/calendar/print-compact', list);
-                                });
+                                print.request('io.ox/calendar/print', list);
+                            } else if (action === 'compact') {
+                                print.request('io.ox/calendar/print-compact', list);
                             }
                         });
                 });
                 return;
             }
-            ox.load(['io.ox/core/print']).done(function (print) {
-                print.request('io.ox/calendar/print', list);
-            });
+            print.request('io.ox/calendar/print', list);
         }
     });
 
     new Action('io.ox/calendar/detail/actions/print-appointment-disabled', {
         requires: 'one',
-        capabilities: 'printing',
+        capabilities: 'calendar-printing',
         action: function (baton) {
-            ox.load(['io.ox/core/print']).done(function (print) {
-                var options = { template: 'print.appointment.tmpl' },
-                    POS = 'recurrence_position';
-                if (baton.data[POS]) options[POS] = baton.data[POS];
-                print.open('calendar', baton.data, options);
-            });
+            var options = { template: 'print.appointment.tmpl' },
+                POS = 'recurrence_position';
+            if (baton.data[POS]) options[POS] = baton.data[POS];
+            print.open('calendar', baton.data, options);
         }
     });
 
     new Action('io.ox/calendar/detail/actions/print', {
-        capabilities: 'printing',
+        capabilities: 'calendar-printing',
         requires: function (e) {
             var win = e.baton.window;
             if (_.device('!smartphone') && win && win.getPerspective) {
                 var pers = win.getPerspective();
                 return pers && pers.print;
-            } else {
-                return false;
             }
+            return false;
         },
         action: function (baton) {
             var win = baton.app.getWindow(),
@@ -373,6 +375,18 @@ define('io.ox/calendar/actions', [
         }
     });
 
+    new Action('io.ox/calendar/premium/actions/share', {
+        capabilities: 'caldav client-onboarding',
+        requires: function () {
+            return _.device('!smartphone');
+        },
+        action: function () {
+            require(['io.ox/onboarding/clients/wizard'], function (wizard) {
+                wizard.run();
+            });
+        }
+    });
+
     // Mobile multi select extension points
     // delete appointment(s)
     ext.point('io.ox/calendar/mobileMultiSelect/toolbar').extend({
@@ -383,7 +397,7 @@ define('io.ox/calendar/actions', [
             $(this).append($('<div class="toolbar-button">')
                 .append($('<a href="#">')
                     .append(
-                        $('<i class="fa fa-trash-o">')
+                        $('<i class="fa fa-trash-o" aria-hidden="true">')
                             .on('click', { grid: data.grid }, function (e) {
                                 e.preventDefault();
                                 e.stopPropagation();
@@ -405,7 +419,7 @@ define('io.ox/calendar/actions', [
             $(this).append($('<div class="toolbar-button">')
                 .append($('<a href="#">')
                     .append(
-                        $('<i class="fa fa-sign-in">')
+                        $('<i class="fa fa-sign-in" aria-hidden="true">')
                             .on('click', { grid: data.grid }, function (e) {
                                 e.preventDefault();
                                 e.stopPropagation();
@@ -448,13 +462,23 @@ define('io.ox/calendar/actions', [
         index: 300,
         prio: 'hi',
         mobile: 'lo',
+        id: 'follow-up',
+        //#. Calendar: Create follow-up appointment. Maybe "Folgetermin" in German.
+        label: gt('Follow-up'),
+        ref: 'io.ox/calendar/detail/actions/follow-up'
+    }));
+
+    ext.point('io.ox/calendar/links/inline').extend(new links.Link({
+        index: 400,
+        prio: 'hi',
+        mobile: 'lo',
         id: 'delete',
         label: gt('Delete'),
         ref: 'io.ox/calendar/detail/actions/delete'
     }));
 
     ext.point('io.ox/calendar/links/inline').extend(new links.Link({
-        index: 400,
+        index: 500,
         prio: 'lo',
         mobile: 'lo',
         id: 'move',
@@ -464,7 +488,7 @@ define('io.ox/calendar/actions', [
     }));
 
     ext.point('io.ox/calendar/links/inline').extend(new links.Link({
-        index: 500,
+        index: 600,
         prio: 'lo',
         id: 'print',
         label: gt('Print'),
@@ -504,4 +528,19 @@ define('io.ox/calendar/actions', [
         label: gt('Save as distribution list'),
         ref: 'io.ox/calendar/detail/actions/save-as-distlist'
     }));
+
+    ext.point('io.ox/calendar/folderview/premium-area').extend(new links.InlineLinks({
+        index: 100,
+        id: 'inline-premium-links',
+        ref: 'io.ox/calendar/links/premium-links',
+        classes: 'list-unstyled'
+    }));
+
+    ext.point('io.ox/calendar/links/premium-links').extend(new links.Link({
+        index: 100,
+        prio: 'hi',
+        id: 'share-calendar',
+        label: gt('Synchronize calendar'),
+        ref: 'io.ox/calendar/premium/actions/share'
+    }));
 });
