@@ -61,10 +61,12 @@ define('io.ox/calendar/api', [
                 })
                 .done(function (data) {
                     api.caches.get[key] = data;
+                }).fail(function (error) {
+                    api.trigger('error error:' + error.code, error);
+                    return error;
                 });
-            } else {
-                return $.Deferred().resolve(api.caches.get[key]);
             }
+            return $.Deferred().resolve(api.caches.get[key]);
         },
 
         getAll: function (o, useCache) {
@@ -75,7 +77,8 @@ define('io.ox/calendar/api', [
                 order: 'asc'
             }, o || {});
             useCache = useCache === undefined ? true : !!useCache;
-            var key = (o.folder || o.folder_id) + '.' + o.start + '.' + o.end + '.' + o.order,
+            var folderId = o.folder !== undefined ? o.folder : o.folder_id,
+                key = folderId + '.' + o.start + '.' + o.end + '.' + o.order,
                 params = {
                     action: 'all',
                     // id, folder_id, last_modified, private_flag, color_label, recurrence_id, recurrence_position, start_date,
@@ -101,10 +104,12 @@ define('io.ox/calendar/api', [
                 })
                 .done(function (data) {
                     api.caches.all[key] = JSON.stringify(data);
+                }).fail(function (error) {
+                    api.trigger('error error:' + error.code, error);
+                    return error;
                 });
-            } else {
-                return $.Deferred().resolve(JSON.parse(api.caches.all[key]));
             }
+            return $.Deferred().resolve(JSON.parse(api.caches.all[key]));
         },
 
         getList: function (ids) {
@@ -159,9 +164,8 @@ define('io.ox/calendar/api', [
                 .done(function (data) {
                     api.caches.all[key] = JSON.stringify(data);
                 });
-            } else {
-                return $.Deferred().resolve(JSON.parse(api.caches.all[key]));
             }
+            return $.Deferred().resolve(JSON.parse(api.caches.all[key]));
         },
 
         search: function (query) {
@@ -197,67 +201,66 @@ define('io.ox/calendar/api', [
                 key = folder_id + '.' + o.id + '.' + (o.recurrence_position || 0),
                 attachmentHandlingNeeded = o.tempAttachmentIndicator;
 
+            delete o.cid;
             delete o.tempAttachmentIndicator;
 
-            if (_.isEmpty(o)) {
-                return $.when();
-            } else {
-                return http.PUT({
-                    module: 'calendar',
-                    params: {
-                        action: 'update',
-                        id: o.id,
-                        folder: folder_id,
-                        timestamp: o.last_modified || o.timestamp || _.then(),
-                        timezone: 'UTC'
-                    },
-                    data: o,
-                    appendColumns: false
-                })
-                .then(function (obj) {
-                    // check for conflicts
-                    if (!_.isUndefined(obj.conflicts)) {
-                        return $.Deferred().reject(obj);
+            if (_.isEmpty(o)) return $.when();
+
+            return http.PUT({
+                module: 'calendar',
+                params: {
+                    action: 'update',
+                    id: o.id,
+                    folder: folder_id,
+                    timestamp: o.last_modified || o.timestamp || _.then(),
+                    timezone: 'UTC'
+                },
+                data: o,
+                appendColumns: false
+            })
+            .then(function (obj) {
+                // check for conflicts
+                if (!_.isUndefined(obj.conflicts)) {
+                    return $.Deferred().reject(obj);
+                }
+
+                checkForNotification(o);
+
+                var getObj = {
+                    id: obj.id || o.id,
+                    folder: folder_id
+                };
+
+                if (o.recurrence_position && o.recurrence_position !== null && obj.id === o.id) {
+                    getObj.recurrence_position = o.recurrence_position;
+                }
+
+                // clear caches
+                api.caches.all = {};
+                delete api.caches.get[key];
+                // if master, delete all appointments from cache
+                if (o.recurrence_type > 0 && !o.recurrence_position) {
+                    var deleteKey = folder_id + '.' + o.id;
+                    for (var i in api.caches.get) {
+                        if (i.indexOf(deleteKey) === 0) delete api.caches.get[i];
                     }
+                }
 
-                    checkForNotification(o);
-
-                    var getObj = {
-                        id: obj.id || o.id,
-                        folder: folder_id
-                    };
-
-                    if (o.recurrence_position && o.recurrence_position !== null && obj.id === o.id) {
-                        getObj.recurrence_position = o.recurrence_position;
-                    }
-
-                    // clear caches
-                    api.caches.all = {};
-                    delete api.caches.get[key];
-                    // if master, delete all appointments from cache
-                    if (o.recurrence_type > 0 && !o.recurrence_position) {
-                        var deleteKey = folder_id + '.' + o.id;
-                        for ( var i in api.caches.get ) {
-                            if (i.indexOf(deleteKey) === 0) delete api.caches.get[i];
+                return api.get(getObj)
+                    .then(function (data) {
+                        if (attachmentHandlingNeeded) {
+                            //to make the detailview show the busy animation
+                            api.addToUploadList(_.ecid(data));
                         }
-                    }
-
-                    return api.get(getObj)
-                        .then(function (data) {
-                            if (attachmentHandlingNeeded) {
-                                //to make the detailview show the busy animation
-                                api.addToUploadList(_.ecid(data));
-                            }
-                            api.trigger('update', data);
-                            api.trigger('update:' + _.ecid(o), data);
-                            return data;
-                        });
-                }, function (error) {
-                    api.caches.all = {};
-                    api.trigger('delete', o);
-                    return error;
-                });
-            }
+                        api.trigger('update', data);
+                        api.trigger('update:' + _.ecid(o), data);
+                        return data;
+                    });
+            }, function (error) {
+                api.caches.all = {};
+                api.trigger('delete', o);
+                return error;
+            });
         },
 
         /**
@@ -279,7 +282,7 @@ define('io.ox/calendar/api', [
                 // if master, delete all appointments from cache
                 if (o.recurrence_type > 0 && !o.recurrence_position) {
                     var deleteKey = folder_id + '.' + o.id;
-                    for ( var i in api.caches.get ) {
+                    for (var i in api.caches.get) {
                         if (i.indexOf(deleteKey) === 0) delete api.caches.get[i];
                     }
                 }
@@ -304,6 +307,7 @@ define('io.ox/calendar/api', [
          */
         create: function (o) {
             var attachmentHandlingNeeded = o.tempAttachmentIndicator;
+            delete o.cid;
             delete o.tempAttachmentIndicator;
             return http.PUT({
                 module: 'calendar',
@@ -563,12 +567,11 @@ define('io.ox/calendar/api', [
 
             var now = _.now(),
                 start = moment(now).subtract(2, 'hours').valueOf(),
-                end = moment(now).add(5, 'years').valueOf();
+                end = moment(now).add(2, 'years').valueOf();
 
             return this.getUpdates({
                 folder: 'all',
                 start: start,
-                // 5 years like OX6
                 end: end,
                 timestamp: 0,
                 recurrence_master: true
@@ -660,10 +663,9 @@ define('io.ox/calendar/api', [
                     if (_.isString(obj)) {
                         // use fresh server data
                         return (api.caches.freebusy[obj] = response.shift());
-                    } else {
-                        // use cached data
-                        return obj;
                     }
+                    // use cached data
+                    return obj;
                 });
             });
         },
@@ -800,6 +802,19 @@ define('io.ox/calendar/api', [
         }
     });
 
+    folderAPI.on({
+        'before:remove before:move': function (data) {
+            if (data.module === 'calendar') {
+                //remove cache for "All my appointments"
+                var cleanedAllCache = _.omit(api.caches.all, function (value, key) {
+                    return key.split('.')[0] === '0';
+                });
+                api.caches.all = cleanedAllCache;
+            }
+
+        }
+    });
+
     ox.on('refresh^', function () {
         api.refresh();
     });
