@@ -26,12 +26,19 @@ define('io.ox/calendar/freebusy/controller', [
     'io.ox/calendar/view-detail',
     'gettext!io.ox/calendar/freebusy',
     'settings!io.ox/core',
+    'settings!io.ox/calendar',
     'less!io.ox/calendar/week/style',
     'less!io.ox/calendar/freebusy/style'
-], function (dialogs, WeekView, templates, folderAPI, AddParticipant, pModel, pView, userAPI, contactsUtil, api, notifications, detailView, gt, settings) {
+], function (dialogs, WeekView, templates, folderAPI, AddParticipantView, pModel, pView, userAPI, contactsUtil, api, notifications, detailView, gt, settings, settingsCalendar) {
 
     'use strict';
 
+    // ensure cid is used in model and collection as idAttribute properly
+    // to ensure appointments of series are handled correctly (same id)
+    var FreebusyCollection = Backbone.Collection.extend({
+        model: Backbone.Model.extend({ idAttribute: 'cid' })
+    });
+
     var that = {
 
         FreeBusy: function (options) {
@@ -42,7 +49,7 @@ define('io.ox/calendar/freebusy/controller', [
                 // short-term fluent appointment cache
                 cache = {},
                 // dummy collection
-                emptyCollection = new Backbone.Collection([]),
+                emptyCollection = new FreebusyCollection([]),
                 // calendar views (day, workweek, week)
                 currentMode = '',
                 calendarViews = {},
@@ -141,11 +148,6 @@ define('io.ox/calendar/freebusy/controller', [
                 return model ? model.index : 0;
             }
 
-            function getResourceTitleByIndex(index) {
-                var model = self.participants.at(index);
-                return model ? model.get('display_name') : '';
-            }
-
             this.loadAppointments = function (useCache) {
                 var list = self.getParticipants(),
                     options = self.getCalendarView().getRequestParam();
@@ -167,11 +169,8 @@ define('io.ox/calendar/freebusy/controller', [
                                         obj.index = getColorByIndex(index);
                                         // add appointments without access to cache
                                         cache[_.cid(obj)] = obj;
-                                        // check participnat type
-                                        var part = list[index];
-                                        if (part && part.type === 3) {
-                                            obj.title = getResourceTitleByIndex(index);
-                                        }
+                                        // do not show private flag icon
+                                        obj.private_flag = false;
                                         return obj;
                                     })
                                     .value();
@@ -236,7 +235,7 @@ define('io.ox/calendar/freebusy/controller', [
             };
 
             // all appointments are stored in this collection
-            this.appointments = new Backbone.Collection([]);
+            this.appointments = new FreebusyCollection([]);
 
             this.getCalendarView = function () {
                 return calendarViews ? calendarViews[currentMode] : null;
@@ -244,8 +243,10 @@ define('io.ox/calendar/freebusy/controller', [
 
             this.bubble = function (eventname, e, data) {
                 // get calendar app
-                var parentapp = options.baton && options.baton.app ? options.baton.app : $();
-                parentapp.trigger(eventname, e, data, 'freebusy-' + this.getCalendarView().mode);
+                var view = this.getCalendarView();
+                if (!view) return;
+                var app = options.baton && options.baton.app ? options.baton.app : $();
+                app.trigger(eventname, e, data, 'freebusy-' + view.mode);
             };
 
             this.getCalendarViewInstance = function (mode) {
@@ -304,7 +305,9 @@ define('io.ox/calendar/freebusy/controller', [
                         // whole-day / all-day / full-time
                         .addClass(model.get('full_time') ? 'fulltime' : '')
                         // temporary
-                        .addClass(model.get('shown_as') === 2 ? 'striped' : '');
+                        .addClass(model.get('shown_as') === 2 ? 'striped' : '')
+                        // no read access: disable (no click handler, default pointer, no hover)
+                        .addClass(!model.get('folder_id') && settingsCalendar.get('freeBusyStrict', true) ? 'disabled' : '');
                     return $el;
                 };
 
@@ -422,9 +425,9 @@ define('io.ox/calendar/freebusy/controller', [
 
             var drop;
 
-            this.autocomplete = new AddParticipant({
+            this.autocomplete = new AddParticipantView({
                 apiOptions: {
-                    contacts: true,
+                    contacts: false,
                     users: true,
                     groups: true,
                     resources: true,
