@@ -26,7 +26,19 @@ define('io.ox/calendar/month/perspective', [
 
     'use strict';
 
-    var perspective = new ox.ui.Perspective('month');
+    var perspective = new ox.ui.Perspective('month'),
+        // ensure cid is used in model and collection as idAttribute properly
+        MonthAppointment = Backbone.Model.extend({
+            idAttribute: 'cid',
+            initialize: function () {
+                this.cid = this.attributes.cid = _.cid(this.attributes);
+                // backward compatibility
+                this.id = this.cid;
+            }
+        }),
+        MonthAppointmentCollection = Backbone.Collection.extend({
+            model: MonthAppointment
+        });
 
     _.extend(perspective, {
 
@@ -148,7 +160,7 @@ define('io.ox/calendar/month/perspective', [
         updateWeeks: function (opt, useCache) {
             // fetch appointments
             var self = this,
-                weeks = opt.weeks || this.updateLoad,
+                weeks = opt.weeks || this.updateLoad,
                 apiData = {
                     start: opt.start,
                     end: moment(opt.start).add(weeks, 'weeks').valueOf()
@@ -158,33 +170,25 @@ define('io.ox/calendar/month/perspective', [
                 apiData.folder = this.folder.id;
             }
 
-            return api.getAll(apiData, useCache).done(function (list) {
+            return api.getAll(apiData, useCache).then(function (list) {
                 // update single week view collections
+                function appointmentsBetween(start, end) {
+                    return list.filter(function (mod) {
+                        var tmpStart = mod.full_time ? moment.utc(mod.start_date).local(true).valueOf() : mod.start_date,
+                            tmpEnd = mod.full_time ? moment.utc(mod.end_date).local(true).valueOf() : mod.end_date;
+                        return (tmpStart >= start && tmpStart < end) || (tmpEnd > start && tmpEnd <= end) || (tmpStart <= start && tmpEnd >= end);
+                    }).map(function (obj) {
+                        return new MonthAppointment(obj);
+                    });
+                }
                 var start = opt.start;
-                for (var i = 1; i <= weeks; i++) {
-                    var end = moment(start).add(1, 'week').valueOf(),
+                for (var i = 0; i < weeks; i++) {
+                    var end = moment(start).endOf('week').valueOf(),
                         collection = self.collections[start];
                     if (collection) {
-                        var retList = [];
-                        if (list.length > 0) {
-                            for (var j = 0; j < list.length; j++) {
-                                var mod = list[j],
-                                    tmpStart = mod.start_date,
-                                    tmpEnd = mod.end_date;
-                                if (mod.full_time) {
-                                    tmpStart = moment.utc(tmpStart).local(true).valueOf();
-                                    tmpEnd = moment.utc(tmpEnd).local(true).valueOf();
-                                }
-                                if ((tmpStart >= start && tmpStart < end) || (tmpEnd > start && tmpEnd <= end) || (tmpStart <= start && tmpEnd >= end)) {
-                                    var m = new Backbone.Model(mod);
-                                    m.id = _.cid(mod);
-                                    retList.push(m);
-                                }
-                            }
-                        }
-                        collection.reset(retList);
+                        collection.reset(appointmentsBetween(start, end));
                     }
-                    start = moment(start).add(1, 'week').valueOf();
+                    start = moment(start).add(8, 'd').startOf('week').valueOf();
                     collection = null;
                 }
             });
@@ -217,13 +221,13 @@ define('io.ox/calendar/month/perspective', [
             }
 
             // draw all weeks
-            for (var i = 1; i <= weeks; i++, curWeek.add(1, 'week')) {
+            for (var i = 0; i < weeks; i++, curWeek.add(8, 'd').startOf('week')) {
                 var day = curWeek.valueOf(),
-                    endDate = moment(curWeek).add(1, 'week'),
-                    monthDelimiter = curWeek.date() > endDate.date();
+                    endDate = curWeek.clone().endOf('week'),
+                    monthDelimiter = curWeek.clone().endOf('month').isBefore(endDate.clone().add(1, 'd'));
 
                 // add collection for week
-                self.collections[day] = new Backbone.Collection([]);
+                self.collections[day] = new MonthAppointmentCollection([]);
                 // new view
                 var view = createView({
                     collection: self.collections[day],
@@ -237,11 +241,13 @@ define('io.ox/calendar/month/perspective', [
 
                 // seperate last days if month before and first days of next month
                 if (monthDelimiter) {
+                    endDate.add(1, 'd').startOf('month');
                     // add an
-                    views.push($('<div class="week month-name">').attr('id', endDate.year() + '-' + endDate.month()).append($('<div>').text(gt.noI18n(endDate.format('MMMM YYYY')))));
+                    views.push($('<div class="week month-name">').attr('id', endDate.format('YYYY-MM')).append($('<div>').text(gt.noI18n(endDate.format('MMMM YYYY')))));
                     view.$el.addClass('no-border');
 
-                    if (endDate.date() != 1) {
+                    if (!endDate.clone().startOf('week').isSame(endDate)) {
+                        // do not render this, if start of current week is the same as start of current month
                         views.push(createView({
                             collection: self.collections[day],
                             day: day,
@@ -357,8 +363,10 @@ define('io.ox/calendar/month/perspective', [
                 }
             }
 
-            var firstDay = $('#' + target.year() + '-' + target.month(), self.pane),
-                nextFirstDay = $('#' + target.year() + '-' + (target.month() + 1), self.pane),
+            // we cannot use target.month() + 1 or we might get month 13 in 2015 instead of month 1 in 2016
+            var nextMonth = moment(target).add(1, 'month'),
+                firstDay = $('#' + target.format('YYYY-MM'), self.pane),
+                nextFirstDay = $('#' + nextMonth.format('YYYY-MM'), self.pane),
                 scrollToDate = function () {
                     // scroll to position
                     if (firstDay.length === 0) return;
@@ -367,18 +375,16 @@ define('io.ox/calendar/month/perspective', [
 
             if (firstDay.length > 0 && nextFirstDay.length > 0) {
                 scrollToDate();
+            } else if (target.valueOf() < self.current.valueOf()) {
+                this.drawWeeks({ up: true }).done(function () {
+                    firstDay = $('#' + target.format('YYYY-MM'), self.pane);
+                    scrollToDate();
+                });
             } else {
-                if (target.valueOf() < self.current.valueOf()) {
-                    this.drawWeeks({ up: true }).done(function () {
-                        firstDay = $('#' + target.year() + '-' + target.month(), self.pane);
-                        scrollToDate();
-                    });
-                } else {
-                    this.drawWeeks().done(function () {
-                        firstDay = $('#' + target.year() + '-' + target.month(), self.pane);
-                        scrollToDate();
-                    });
-                }
+                this.drawWeeks().done(function () {
+                    firstDay = $('#' + target.format('YYYY-MM'), self.pane);
+                    scrollToDate();
+                });
             }
         },
 
@@ -479,12 +485,12 @@ define('io.ox/calendar/month/perspective', [
                 var toolbarNode = $('<div>')
                     .addClass('controls-container')
                     .append(
-                        $('<a href="#" tabindex="1" role="button">').addClass('control prev').append($('<i class="fa fa-chevron-left">'))
+                        $('<a href="#" tabindex="1" role="button">').addClass('control prev').append($('<i class="fa fa-chevron-left" aria-hidden="true">'))
                         .on('click', $.proxy(function (e) {
                             e.preventDefault();
                             this.gotoMonth('prev');
                         }, this)),
-                        $('<a href="#" tabindex="1" role="button">').addClass('control next').append($('<i class="fa fa-chevron-right">'))
+                        $('<a href="#" tabindex="1" role="button">').addClass('control next').append($('<i class="fa fa-chevron-right" aria-hidden="true">'))
                         .on('click', $.proxy(function (e) {
                             e.preventDefault();
                             this.gotoMonth('next');
@@ -526,7 +532,7 @@ define('io.ox/calendar/month/perspective', [
                         month = this.tops[y].data('date');
                     }
 
-                    if (prevMonth != this.previous.valueOf()) {
+                    if (prevMonth !== this.previous.valueOf()) {
                         this.previous = moment(prevMonth);
                     }
 
@@ -558,20 +564,20 @@ define('io.ox/calendar/month/perspective', [
             this.main
                 .on('keydown', function (e) {
                     switch (e.which) {
-                    case 37:
-                        // left
-                        self.gotoMonth('prev');
-                        break;
-                    case 39:
-                        // right
-                        self.gotoMonth('next');
-                        break;
-                    case 13:
-                        // enter
-                        $(e.target).click();
-                        break;
-                    default:
-                        break;
+                        case 37:
+                            // left
+                            self.gotoMonth('prev');
+                            break;
+                        case 39:
+                            // right
+                            self.gotoMonth('next');
+                            break;
+                        case 13:
+                            // enter
+                            $(e.target).click();
+                            break;
+                        default:
+                            break;
                     }
                 });
 
