@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
@@ -149,14 +150,15 @@ define('io.ox/calendar/month/view', [
                     (day.isWeekend ? ' weekend' : '') +
                     (day.isFirst || i === 0 ? ' borderleft' : '') +
                     (day.isLast ? ' borderright' : '') +
+                    /*eslint-disable no-nested-ternary */
                     (list.hasFirst ? (firstFound ? ' bordertop' : ' borderbottom') : '') +
+                    /*eslint-enable no-nested-ternary */
                     (list.hasLast && !firstFound ? ' borderbottom' : '')
                 );
 
                 if ((this.weekType === 'first' && !firstFound) || (this.weekType === 'last' && firstFound)) {
                     this.$el.append(dayCell.addClass('day-filler'));
                 } else {
-                    var dayCell;
                     this.$el.append(
                         dayCell
                         .addClass('day')
@@ -188,9 +190,9 @@ define('io.ox/calendar/month/view', [
                     .addClass('appointment')
                     .data('app', a)
                     .attr({
-                        'data-cid': a.id,
+                        'data-cid': a.cid,
                         'data-extension-point': 'io.ox/calendar/month/view/appointment',
-                        'data-composite-id': a.id
+                        'data-composite-id': a.cid
                     });
 
             ext.point('io.ox/calendar/month/view/appointment')
@@ -234,11 +236,9 @@ define('io.ox/calendar/month/view', [
                     if (tempDate === undefined) {
                         // first run, draw
                         this.renderAppointmentIndicator(cell);
-                    } else {
-                        if (!startMoment.isSame(tempDate, 'day')) {
-                            // one mark per day is enough
-                            this.renderAppointmentIndicator(cell);
-                        }
+                    } else if (!startMoment.isSame(tempDate, 'day')) {
+                        // one mark per day is enough
+                        this.renderAppointmentIndicator(cell);
                     }
                     // remember for next run
                     tempDate = startMoment.clone();
@@ -283,10 +283,9 @@ define('io.ox/calendar/month/view', [
                         //revert the peg by returning true
                         $(this).show();
                         return true;
-                    } else {
-                        //return false so that the peg does not revert
-                        return false;
                     }
+                    //return false so that the peg does not revert
+                    return false;
                 },
                 start: function () {
                     $(this).hide();
@@ -348,7 +347,7 @@ define('io.ox/calendar/month/view', [
             function addColorClasses(f) {
                 self.addClass(util.getAppointmentColorClass(f, a.attributes));
                 if (util.canAppointmentChangeColor(f, a.attributes)) {
-                    self.attr('data-folder',  f.id);
+                    self.attr('data-folder', f.id);
                 }
             }
 
@@ -384,7 +383,7 @@ define('io.ox/calendar/month/view', [
                     .addClass('appointment-content')
                     .css('lineHeight', (a.get('full_time') ? this.fulltimeHeight : this.cellHeight) + 'px')
                     .append(
-                        a.get('private_flag') ? $('<span class="private-flag"><i class="fa fa-lock"></i></span>') : '',
+                        a.get('private_flag') ? $('<span class="private-flag"><i class="fa fa-lock" aria-hidden="true"></i></span>') : '',
                         a.get('title') ? $('<div>').addClass('title').text(gt.format(confString, gt.noI18n(a.get('title') || '\u00A0'))) : '',
                         a.get('location') ? $('<div>').addClass('location').text(gt.noI18n(a.get('location') || '\u00A0')) : ''
                     )
@@ -405,7 +404,7 @@ define('io.ox/calendar/month/view', [
         id: 'default',
         index: 100,
         draw: function () {
-            this.append('<i class="fa fa-circle">');
+            this.append('<i class="fa fa-circle" aria-hidden="true">');
         }
     });
 
