@@ -23,10 +23,11 @@ define('io.ox/calendar/view-detail', [
     'io.ox/core/extPatterns/links',
     'io.ox/participants/detail',
     'io.ox/core/util',
+    'settings!io.ox/calendar',
     'gettext!io.ox/calendar',
     'io.ox/calendar/actions',
     'less!io.ox/calendar/style'
-], function (ext, util, calAPI, userAPI, groupAPI, resourceAPI, folderAPI, attachments, links, ParticipantsView, coreUtil, gt) {
+], function (ext, util, calAPI, userAPI, groupAPI, resourceAPI, folderAPI, attachments, links, ParticipantsView, coreUtil, settings, gt) {
 
     'use strict';
 
@@ -47,7 +48,7 @@ define('io.ox/calendar/view-detail', [
         draw: function (baton) {
             if (!baton.data.private_flag) return;
             this.append(
-                $('<i class="fa fa-lock private-flag">')
+                $('<i class="fa fa-lock private-flag" aria-hidden="true">')
             );
         }
     });
@@ -81,14 +82,7 @@ define('io.ox/calendar/view-detail', [
             id: 'date',
             draw: function (baton) {
                 this.append(
-                    $('<div class="date-time">').append(
-                        // date
-                        $('<span class="date">').text(util.getDateInterval(baton.data)),
-                        // mdash
-                        $.txt(' \u00A0 '),
-                        // time
-                        util.addTimezoneLabel($('<span class="time">'), baton.data, { placement: 'top' })
-                    )
+                    util.getDateTimeIntervalMarkup(baton.data)
                 );
             }
         },
@@ -153,6 +147,7 @@ define('io.ox/calendar/view-detail', [
     $(document).on('click', '.expandable-toggle', function (e) {
         e.preventDefault();
         $(this).closest('fieldset').toggleClass('open');
+        $(this).attr('aria-expanded', $(this).closest('fieldset').hasClass('open'));
     });
 
     // draw details
@@ -162,7 +157,7 @@ define('io.ox/calendar/view-detail', [
         draw: function (baton, options) {
 
             // we don't show details for private appointments in shared/public folders (see bug 37971)
-            var data = baton.data, folder = folderAPI.pool.getModel(data.folder_id);
+            var data = baton.data, folder = options.minimaldata ? {} : folderAPI.pool.getModel(data.folder_id);
             if (data.private_flag && data.created_by !== ox.user_id && !folderAPI.is('private', folder)) return;
 
             var node = $('<dl class="dl-horizontal expandable-content">');
@@ -170,14 +165,14 @@ define('io.ox/calendar/view-detail', [
             this.append(
                 $('<fieldset class="details expandable">').append(
                     $('<legend class="io-ox-label">').append(
-                        $('<a href="#" class="expandable-toggle" role="button">').append(
+                        $('<a href="#" class="expandable-toggle" role="button" aria-expanded="false">').append(
                             $('<h2>').text(gt('Details'))
                         ),
                         $.txt(' '),
-                        $('<i class="fa expandable-indicator">')
+                        $('<i class="fa expandable-indicator" aria-hidden="true">')
                     ),
                     node
-                )
+                ).addClass(options.minimaldata ? 'open' : '')
             );
         }
     });
@@ -198,14 +193,14 @@ define('io.ox/calendar/view-detail', [
                 $('<dd class="detail organizer">').append(
                     coreUtil.renderPersonalName(
                         baton.data.organizerId ?
-                        {
-                            html: userAPI.getTextNode(baton.data.organizerId),
-                            user_id: baton.data.organizerId
-                        } : {
-                            name: baton.data.organizer,
-                            email: baton.data.organizer
-                        },
-                        baton.data
+                            {
+                                html: userAPI.getTextNode(baton.data.organizerId),
+                                user_id: baton.data.organizerId
+                            } : {
+                                name: baton.data.organizer,
+                                email: baton.data.organizer
+                            },
+                            baton.data
                     )
                 )
             );
@@ -248,7 +243,7 @@ define('io.ox/calendar/view-detail', [
         }
     });
 
-    function getDeepLink (data) {
+    function getDeepLink(data) {
         return [
             ox.abs,
             ox.root,
@@ -409,7 +404,7 @@ define('io.ox/calendar/view-detail', [
         draw: function (baton, options) {
             // make sure we have a baton
             baton = ext.Baton.ensure(baton);
-            options = _.extend({}, options);
+            options = _.extend({ minimaldata: !baton.data.folder_id }, options);
             if (_.device('smartphone') && !options.deeplink) {
                 baton.disable('io.ox/calendar/detail/actions', 'inline-links');
             }
