@@ -140,12 +140,6 @@ define('io.ox/contacts/main', [
                 classes: 'rightside'
             });
 
-            app.getTour = function () {
-                //no tours for guests, yet. See bug 41542
-                if (capabilities.has('guest')) return;
-
-                return { id: 'default/io.ox/contacts', path: 'io.ox/tours/contacts' };
-            };
         },
 
         'folder-view-mobile': function (app) {
@@ -197,7 +191,7 @@ define('io.ox/contacts/main', [
                 build: function () {
                     var name, description, private_flag;
                     this.addClass('contact').append(
-                        private_flag = $('<i class="fa fa-lock private_flag">').hide(),
+                        private_flag = $('<i class="fa fa-lock private_flag" aria-hidden="true">').hide(),
                         name = $('<div class="fullname">').attr('aria-hidden', true),
                         description = $('<div class="bright-text">').attr('aria-hidden', true)
                     );
@@ -770,6 +764,56 @@ define('io.ox/contacts/main', [
             commons.mediateFolderView(app);
         },
 
+        'premium-area': function (app) {
+            commons.addPremiumFeatures(app, {
+                upsellId: 'folderview/contacts/bottom',
+                upsellRequires: 'carddav'
+            });
+        },
+
+        /*
+         * change to default folder on no permission or folder not found errors
+         */
+        'no-permission': function (app) {
+            // use debounce, so errors from folder and app api are only handled once.
+            var handleError = _.debounce(function (error) {
+                // work with (error) and (event, error) arguments
+                if (error && !error.error) {
+                    if (arguments[1] && arguments[1].error) {
+                        error = arguments[1];
+                    } else {
+                        return;
+                    }
+                }
+                // only change if folder is currently displayed
+                if (error.error_params[0] && String(app.folder.get()) !== String(error.error_params[0])) {
+                    return;
+                }
+                require(['io.ox/core/yell'], function (yell) {
+                    yell(error);
+                    // try to load the default folder
+                    // guests do not have a default folder, so the first visible one is chosen
+                    app.folder.setDefault();
+                });
+            }, 300);
+
+            folderAPI.on('error:FLD-0008', handleError);
+            api.on('error:FLD-0008', handleError);
+            api.on('error:CON-0104', function (e, error) {
+                // check if folder is currently displayed
+                if (String(app.folder.get()) !== String(error.error_params[0])) {
+                    return;
+                }
+                // see if we can still access the folder, although we are not allowed to view the contents
+                // this is important because otherwise we would not be able to change permissions (because the view jumps to the default folder all the time)
+                folderAPI.get(app.folder.get(), { cache: false }).fail(function (error) {
+                    if (error.code === 'FLD-0003') {
+                        handleError(error);
+                    }
+                });
+            });
+        },
+
         'api-events': function (app) {
             api.on('create update delete refresh.all', function () {
                 folderAPI.reload(app.folder.get());
@@ -796,7 +840,7 @@ define('io.ox/contacts/main', [
 
         'inplace-find': function (app) {
 
-            if (_.device('smartphone') || !capabilities.has('search')) return;
+            if (_.device('smartphone') || !capabilities.has('search')) return;
 
             app.searchable();
         },
