@@ -25,8 +25,11 @@ define('io.ox/contacts/view-detail', [
     'io.ox/core/util',
     'io.ox/core/capabilities',
     'gettext!io.ox/contacts',
+    'settings!io.ox/contacts',
+    'io.ox/core/tk/attachments',
+    'io.ox/core/http',
     'less!io.ox/contacts/style'
-], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, capabilities, gt) {
+], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, capabilities, gt, settings, attachments, http) {
 
     'use strict';
 
@@ -97,7 +100,7 @@ define('io.ox/contacts/view-detail', [
         id: 'inline-actions',
         draw: function (baton) {
             if (!api.looksLikeResource(baton.data)) {
-                ext.point('io.ox/contacts/detail/actions').invoke('draw', this, baton.data);
+                ext.point('io.ox/contacts/detail/actions').invoke('draw', this, baton);
             }
         }
     });
@@ -108,7 +111,7 @@ define('io.ox/contacts/view-detail', [
         draw: function (baton) {
             var node;
             this.append(
-                node = $('<header class="contact-header" role="heading">')
+                node = $('<header class="contact-header">')
             );
             ext.point('io.ox/contacts/detail/head').invoke('draw', node, baton);
         }
@@ -254,18 +257,19 @@ define('io.ox/contacts/view-detail', [
             }
 
             // remove duplicates to fix backend bug
+            http.pause();
             _(list)
                 .chain()
                 .filter(function (member) {
                     if (hash[member.mail]) {
                         return false;
-                    } else {
-                        return (hash[member.mail] = true);
                     }
+                    return (hash[member.mail] = true);
                 })
                 .each(function (member) {
                     ext.point('io.ox/contacts/detail/member').invoke('draw', $list, member);
                 }, this);
+            http.resume();
         }
     });
 
@@ -411,7 +415,7 @@ define('io.ox/contacts/view-detail', [
                     .append(
                         $('<address>').text($.trim(text)),
                         $('<p>').append(
-                            $('<i class="fa fa-external-link">'),
+                            $('<i class="fa fa-external-link" aria-hidden="true">'),
                             // \u2122 = &trade;
                             $.txt(' Google Maps \u2122')
                         )
@@ -457,14 +461,7 @@ define('io.ox/contacts/view-detail', [
                         simple(data, 'nickname'),
                         row('birthday', function () {
                             if (baton.data.birthday) {
-                                //use utc time. birthdays must not be converted
-                                var birthday = moment.utc(baton.data.birthday);
-                                if (birthday.year() === 1) {
-                                    //Year 0 is special for birthdays without year (backend changes this to 1...)
-                                    return birthday.format(moment.localeData().longDateFormat('l').replace(/Y/g, ''));
-                                } else {
-                                    return birthday.format('l');
-                                }
+                                return util.getBirthday(baton.data.birthday);
                             }
                         }),
                         row('url', function () {
