@@ -38,6 +38,9 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
 
         function apply(collection, type, params, loader, data) {
 
+            // determine current page size
+            var PAGE_SIZE = type === 'load' ? loader.PRIMARY_PAGE_SIZE : loader.SECONDARY_PAGE_SIZE;
+
             // don't use loader.collection to avoid cross-collection issues (see bug 38286)
 
             if (type === 'paginate' && collection.length > 0) {
@@ -48,21 +51,32 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
                 if (last.head) last = last.head;
                 // compare
                 if (_.cid(first) !== _.cid(last)) {
+                    if (ox.debug) console.warn('paginate compare fail', _.cid(first), _.cid(last), data);
                     // check d0901724d8050552b5b82c0fdd5be1ccfef50d99 for details
                     params.thread = params.action === 'threadedAll';
-                    loader.reload(params, loader.LIMIT);
+                    loader.reload(params, PAGE_SIZE);
                     return;
                 }
             }
 
             Pool.preserve(function () {
                 var method = methods[type];
-                collection[method](data, { parse: true });
+                if (collection.preserve && type === 'reload') {
+                    // avoid "remove" and "sort" events
+                    // used by all-unseen, for example
+                    collection[method](data, { parse: true, add: true, remove: false, sort: false });
+                } else {
+                    // normal case
+                    collection[method](data, { parse: true });
+                }
             });
 
             // track completeness
-            collection.complete = (type === 'load' && data.length < loader.LIMIT) || (type === 'paginate' && data.length <= 1);
-            if (collection.complete) collection.trigger('complete');
+            var complete = (type === 'load' && data.length < PAGE_SIZE) || (type === 'paginate' && data.length <= 1);
+            if (complete !== collection.complete) {
+                collection.complete = complete;
+                collection.trigger('complete', complete);
+            }
             collection.trigger(type);
         }
 
@@ -89,6 +103,7 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
                 .fail(function (e) {
                     self.done();
                     cb_fail(e);
+                    self.fail(e);
                 });
         }
 
@@ -97,13 +112,17 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
             var collection;
 
             params = this.getQueryParams(params || {});
-            params.limit = '0,' + this.LIMIT;
+            params.limit = '0,' + this.PRIMARY_PAGE_SIZE;
             collection = this.collection = this.getCollection(params);
             this.loading = false;
 
             if (this.isBad(params.folder) || (collection.length > 0 && !collection.expired && collection.sorted && !collection.preserve)) {
                 // reduce too large collections
-                collection.reset(collection.first(this.LIMIT), { silent: true });
+                var pageSize = collection.CUSTOM_PAGE_SIZE || this.PRIMARY_PAGE_SIZE;
+                if (collection.length > pageSize) {
+                    collection.reset(collection.first(pageSize), { silent: true });
+                    collection.complete = false;
+                }
                 _.defer(function () {
                     collection.trigger(collection.complete ? 'reset load cache complete' : 'reset load cache');
                 });
@@ -125,7 +144,7 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
             var offset = Math.max(0, collection.length - 1);
             params = this.getQueryParams(_.extend({ offset: offset }, params));
             if (this.isBad(params.folder)) return collection;
-            params.limit = offset + ',' + (offset + this.LIMIT + 1);
+            params.limit = offset + ',' + (collection.length + this.SECONDARY_PAGE_SIZE);
             this.loading = true;
 
             collection.expired = false;
@@ -140,7 +159,7 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
 
             params = this.getQueryParams(_.extend({ offset: 0 }, params));
             if (this.isBad(params.folder)) return collection;
-            params.limit = '0,' + Math.max(collection.length + (tail || 0), this.LIMIT);
+            params.limit = '0,' + Math.max(collection.length + (tail || 0), this.PRIMARY_PAGE_SIZE);
             this.loading = true;
 
             collection.expired = false;
@@ -160,7 +179,8 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
     _.extend(CollectionLoader.prototype, {
 
         // highly emotional and debatable default
-        LIMIT: 50,
+        PRIMARY_PAGE_SIZE: 50,
+        SECONDARY_PAGE_SIZE: 200,
 
         cid: function (obj) {
             return _(obj || {}).chain()
@@ -224,6 +244,8 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
 
             return http.wait().then(function () {
                 return self.httpGet(module, params).then(function (data) {
+                    // apply filter
+                    if (self.filter) data = _(data).filter(self.filter);
                     // useSlice helps if server request doesn't support "limit"
                     return self.useSlice ? Array.prototype.slice.apply(data, params.limit.split(',')) : data;
                 });
@@ -241,6 +263,8 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
 
         done: function () {
             this.loading = false;
+        },
+        fail: function (/* error */) {
         }
     });
 
