@@ -81,7 +81,7 @@ define('io.ox/core/attachments/backbone', [
             require(['io.ox/files/api'], function (filesAPI) {
                 var meta = _.clone(model.get('meta'));
                 // get URL of preview image
-                meta.previewUrl = filesAPI.getUrl(model.toJSON(), 'view')  + '&scaleType=cover&width=' + size + '&height=' + size;
+                meta.previewUrl = filesAPI.getUrl(model.toJSON(), 'view') + '&scaleType=cover&width=' + size + '&height=' + size;
                 if (!regIsImage.test(model.get('filename'))) meta.previewUrl += '&format=preview_image&session=' + ox.session;
                 def.resolve(meta.previewUrl);
                 model.set('meta', meta);
@@ -132,7 +132,8 @@ define('io.ox/core/attachments/backbone', [
         },
 
         getTitle: function () {
-            return this.get('filename');
+            // attachments from drive may have a sanitized filename
+            return this.get('com.openexchange.file.sanitizedFilename') || this.get('filename');
         },
 
         getShortTitle: function (length) {
