@@ -49,26 +49,22 @@ define('io.ox/core/boot/form', [
         util.debug('Show form ...');
 
         function displayMessageOnly() {
+            hideFormElements();
+        }
+
+        function displayContinue(data) {
+            $('#io-ox-login-button').attr('data-i18n', gt('Continue')).val(gt('Continue'));
+            $('#io-ox-login-restoremail, #io-ox-login-username').val(data.login_name || '').prop('readonly', true);
+            $('#io-ox-login-password').val('');
+        }
+
+        function hideFormElements() {
             // remove all other inputs
             $('#io-ox-login-form div.row')
                 .filter('.username, .password, .options, .buttons')
                 .remove();
         }
 
-        function displayContinue() {
-            $('#io-ox-login-button').attr({
-                'data-i18n': gt('Continue'),
-                placeholder: gt('Continue')
-            });
-            var loginName = _.url.hash('login_name');
-            $('.row.username').hide();
-            $('.row.password').hide();
-            $('#io-ox-forgot-password').hide();
-            if (!_.isEmpty(loginName)) {
-                $('#io-ox-login-restoremail, #io-ox-login-username').val(loginName).prop('readonly', true);
-            }
-        }
-
         function resetPassword() {
             $('#io-ox-login-form').attr({
                 action: '/appsuite/api/share/reset/password',
@@ -142,11 +138,17 @@ define('io.ox/core/boot/form', [
             }
         }
 
-        switch (_.url.hash('login_type')) {
+        var loginType = _.url.hash('login_type'), showContinue = false;
+
+        switch (loginType) {
 
-            // show continue screen
             case 'guest':
-                displayContinue();
+            case 'message_continue':
+                // remove all form elements except buttons
+                $('#io-ox-login-form div.row')
+                    .filter('.username, .password, .options')
+                    .hide();
+                showContinue = true;
                 break;
 
             // show guest login
@@ -187,9 +189,11 @@ define('io.ox/core/boot/form', [
                     } else {
                         $('#io-ox-login-help').text(data.message);
                     }
+                    if (showContinue) displayContinue(data);
                 })
                 .fail(function (e) {
                     util.feedback('error', e.error);
+                    if (showContinue) hideFormElements();
                 });
         }
 
