@@ -43,8 +43,14 @@ define('io.ox/core/emoji/view', [
         },
 
         // when user clicks on emoji. inserts emoji into editor
-        onInsertEmoji: function () {
-            console.warn('Overwrite onInsertEmoji!');
+        onInsertEmoji: function (e) {
+            if (!_.isFunction(this.onInsertEmojiCustom)) {
+                console.warn('Implementation missing: onInsertEmoji!');
+                return;
+            }
+            var icon = $(e.target).data('icon');
+            this.emoji.recent(icon.unicode);
+            this.onInsertEmojiCustom.apply(this, arguments);
         },
 
         // when user clicks on emoji category
@@ -78,7 +84,7 @@ define('io.ox/core/emoji/view', [
             this.currentCategory = '';
             this.currentCollection = '';
 
-            if (options.onInsertEmoji) this.onInsertEmoji = options.onInsertEmoji;
+            if (options.onInsertEmoji) this.onInsertEmojiCustom = options.onInsertEmoji;
 
             // for optional run-time access
             this.$el.data('view', this);
@@ -97,13 +103,13 @@ define('io.ox/core/emoji/view', [
             // add tab-control?
             if (this.showTabs) {
                 node.addClass('emoji-use-tabs').append(
-                    $('<div class="emoji-tabs abs">').append(
+                    $('<div class="emoji-tabs">').append(
                         // we directly use the Japanese terms; no translation
-                        $('<a href="#" class="emoji-tab left abs" tabindex="5">')
+                        $('<a href="#" class="emoji-tab left" tabindex="5">')
                             .attr('data-collection', 'japan_carrier')
                             // 他社共通絵文字
                             .text(this.emoji.getTitle('commonEmoji')),
-                        $('<a href="#" class="emoji-tab right abs" tabindex="5">')
+                        $('<a href="#" class="emoji-tab right" tabindex="5">')
                             .attr('data-collection', 'softbank')
                             // 全絵文字
                             .text(this.emoji.getTitle('allEmoji'))
@@ -112,7 +118,7 @@ define('io.ox/core/emoji/view', [
             }
 
             node.append(
-                $('<div class="emoji-header abs">').append(
+                $('<div class="emoji-header">').append(
                     // Options drop down
                     this.showDropdown ?
                         $('<div class="emoji-options dropdown pull-right">').append(
@@ -129,8 +135,8 @@ define('io.ox/core/emoji/view', [
                     // category name
                     $('<span class="emoji-category">')
                 ),
-                $('<div class="emoji-icons abs">'),
-                $('<div class="emoji-footer abs">')
+                $('<div class="emoji-icons">'),
+                $('<div class="emoji-footer">')
             );
 
             this.$el.append(node);
@@ -277,6 +283,7 @@ define('io.ox/core/emoji/view', [
                 this.$el.toggle();
                 this.isOpen = !this.isOpen;
             }
+            this.trigger('toggle', this.isOpen);
         }
     });
 
