@@ -109,7 +109,7 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
 
                 function fnAddExtension(ext) {
                     if (circleGuard[ext.id]) {
-                        throw 'Circular References detected for extension point ' + self.id + ' and extension ' + ext.id;
+                        throw new Error('Circular References detected for extension point ' + self.id + ' and extension ' + ext.id);
                     }
                     circleGuard[ext.id] = true;
                     var before = befores[ext.id];
@@ -161,7 +161,7 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
 
                 if (extension.invoke) {
                     console.error(extension);
-                    throw 'Extensions must not have their own invoke method';
+                    throw new Error('Extensions must not have their own invoke method');
                 }
 
                 if (!extension.id) {
@@ -214,7 +214,7 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
         this.replace = function (extension) {
 
             if (!extension.id) {
-                throw 'Replacements must have an id!';
+                throw new Error('Replacements must have an id!');
             }
 
             var replaced = false;
@@ -318,11 +318,9 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
             // manual invoke to consider baton
             if (baton instanceof Baton) {
                 return o
-                    .filter(function (ext) {
-                        return !baton.isDisabled(self.id, ext.id) && _.isFunction(ext[name]);
-                    })
                     .map(function (ext) {
                         try {
+                            if (baton.isDisabled(self.id, ext.id) || !_.isFunction(ext[name])) return;
                             // stopped?
                             if (baton.isPropagationStopped()) return;
                             // prevent default?
@@ -335,12 +333,11 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
                             error(e);
                         }
                     });
-            } else {
-                try {
-                    return o.invoke.apply(o, args);
-                } catch (e) {
-                    error(e);
-                }
+            }
+            try {
+                return o.invoke.apply(o, args);
+            } catch (e) {
+                error(e);
             }
         };
 
@@ -511,9 +508,8 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
             id = id || '';
             if (registry[id] !== undefined) {
                 return registry[id];
-            } else {
-                return (registry[id] = new Point({ id: id }));
             }
+            return (registry[id] = new Point({ id: id }));
         },
 
         /**
