@@ -121,6 +121,12 @@ define('io.ox/core/folder/api', [
     // no deep recursion needed here, children are sufficient
     function calculateSubtotal(model) {
         return pool.getCollection(model.id).reduce(function (total, model) {
+            // use account API so it works with non standard accounts as well
+            var type = account.getType(model.get('id'));
+            // don't count trash or spam root folders
+            if (type === 'trash' || type === 'spam') {
+                return total;
+            }
             return total + (model.get('subtotal') || 0) + (model.get('unread') || 0);
         }, 0);
     }
@@ -152,11 +158,11 @@ define('io.ox/core/folder/api', [
         }
     }
 
-    function onChangeSubtotal (model, value) {
+    function onChangeSubtotal(model, value) {
         bubbleSubtotal(model, value, 'subtotal');
     }
 
-    function onChangeUnread (model, value) {
+    function onChangeUnread(model, value) {
         bubbleSubtotal(model, value, 'unread');
         // forward event
         api.trigger('change:unread', model, value);
@@ -187,6 +193,21 @@ define('io.ox/core/folder/api', [
             return !!bits.get('admin');
         },
 
+        supportsInternalSharing: function () {
+            // drive: always enabled
+            if (this.is('drive')) return true;
+            // mail: check gab (webmail, PIM, PIM+infostore)
+            if (this.is('mail')) return capabilities.has('gab');
+            // contacts, calendar, tasks
+            if (this.is('public')) return capabilities.has('edit_public_folders');
+            // non-public foldes
+            return capabilities.has('read_create_shared_folders');
+        },
+
+        supportsInviteGuests: function () {
+            return !this.is('mail') && capabilities.has('invite_guests') && this.supportsInternalSharing();
+        },
+
         // check if the folder can have shares
         supportsShares: function () {
             // for mail folders check "capabilities" bitmask
@@ -240,7 +261,7 @@ define('io.ox/core/folder/api', [
 
         onRemove: function (model) {
             if (isFlat(model.get('module'))) return;
-            pool.getModel(this.id).set('subfolders', this.length > 0);
+            pool.getModel(this.id).set('subscr_subflds', this.length > 0);
             api.trigger('collection:remove', this.id, model);
         }
     });
@@ -270,6 +291,12 @@ define('io.ox/core/folder/api', [
         },
 
         addCollection: function (id, list, options) {
+            // drop 'subfolders' attribute unless all=true (see bug 46677)
+            if (options && !options.all) {
+                _(list).each(function (data) {
+                    delete data.subfolders;
+                });
+            }
             // transform list to models
             var models = _(list).map(this.addModel, this);
             // options
@@ -285,15 +312,20 @@ define('io.ox/core/folder/api', [
             }
             collection[type](models);
             collection.fetched = true;
-            if (this.models[id] && this.models[id].get('module') !== 'system') {
+            // some virtual folders have type undefined. Track subtotal for them too.
+            if (this.models[id] && (this.models[id].get('module') === 'mail' || this.models[id].get('module') === undefined)) {
                 var subtotal = 0;
                 for (var i = 0; i < models.length; i++) {
-                    subtotal += (models[i].get('subtotal') || 0) + (models[i].get('unread') || 0);
-                    // add virtual parent references
-                    if (isVirtual(id)) {
-                        var newParents = models[i].get('virtual_parents');
-                        newParents.push(id);
-                        models[i].set('virtual_parents', _.uniq(newParents));
+                    // use account API so it works with non standard accounts as well
+                    var ctype = account.getType(models[i].get('id'));
+                    if (ctype !== 'trash' && ctype !== 'spam') {
+                        subtotal += (models[i].get('subtotal') || 0) + (models[i].get('unread') || 0);
+                        // add virtual parent references
+                        if (isVirtual(id)) {
+                            var newParents = models[i].get('virtual_parents');
+                            newParents.push(id);
+                            models[i].set('virtual_parents', _.uniq(newParents));
+                        }
                     }
                 }
                 this.models[id].set('subtotal', subtotal);
@@ -377,6 +409,17 @@ define('io.ox/core/folder/api', [
         type: 1
     });
 
+    if (capabilities.has('webmail')) {
+        // only define if the user actually has mail
+        // otherwise the folder refresh tries to fetch 'default0'
+        pool.addModel({
+            folder_id: 'default0',
+            id: 'virtual/all-unseen',
+            module: 'mail',
+            title: gt('Unread messages')
+        });
+    }
+
     //
     // Propagate
     // central hub to coordinate events and caches
@@ -434,7 +477,7 @@ define('io.ox/core/folder/api', [
         return this.getter().done(function (array) {
             _(array).each(injectIndex.bind(null, id));
             pool.addCollection(getCollectionId(id), array);
-            pool.getModel(id).set('subfolders', array.length > 0);
+            pool.getModel(id).set('subscr_subflds', array.length > 0);
         });
     };
 
@@ -449,7 +492,7 @@ define('io.ox/core/folder/api', [
 
         add: function (id, getter) {
             this.hash[id] = new VirtualFolder(id, getter);
-            pool.getModel(id).set('subfolders', true);
+            pool.getModel(id).set('subscr_subflds', true);
         },
 
         concat: function () {
@@ -503,6 +546,9 @@ define('io.ox/core/folder/api', [
         })
         .then(function (data) {
             return renameDefaultCalendarFolders(data);
+        }, function (error) {
+            api.trigger('error error:' + error.code, error);
+            return error;
         })
         .then(function (data) {
             // update/add model
@@ -590,10 +636,13 @@ define('io.ox/core/folder/api', [
             },
             appendColumns: true
         })
-        .then(renameDefaultCalendarFolders)
+        .then(renameDefaultCalendarFolders, function (error) {
+            api.trigger('error error:' + error.code, error);
+            return error;
+        })
         .then(function (array) {
             array = processListResponse(id, array);
-            pool.addCollection(collectionId, array);
+            pool.addCollection(collectionId, array, { all: options.all });
             // to make sure we always get the same result (just data; not timestamp)
             return array;
         });
@@ -751,13 +800,13 @@ define('io.ox/core/folder/api', [
             // loop over results to get proper objects and sort out hidden folders
             _(data).each(function (section, id) {
                 var array = _(section).filter(function (folder) {
-                        // store section / easier than type=1,2,3
-                        if (hash[folder.id]) { hidden.push(folder); return false; }
-                        // sharing?
-                        if (util.is('shared-by-me', folder)) sharing.push(folder);
-                        // otherwise
-                        return true;
-                    });
+                    // store section / easier than type=1,2,3
+                    if (hash[folder.id]) { hidden.push(folder); return false; }
+                    // sharing?
+                    if (util.is('shared-by-me', folder)) sharing.push(folder);
+                    // otherwise
+                    return true;
+                });
                 // inject 'All my appointments' for calender/private
                 if (module === 'calendar' && id === 'private') injectVirtualCalendarFolder(array);
                 // process response and add to pool
@@ -827,10 +876,13 @@ define('io.ox/core/folder/api', [
                     if ('title' in changes) api.trigger('rename', id, model.toJSON());
                 }
                 // fetch subfolders of parent folder to ensure proper order after rename/move
-                if (id !== newId || changes.title || changes.folder_id ) return list(model.get('folder_id'), { cache: false }).then(function () {
-                    pool.getCollection(model.get('folder_id')).sort();
-                    return newId;
-                });
+                if (id !== newId || changes.title || changes.folder_id) {
+                    return list(model.get('folder_id'), { cache: false })
+                            .then(function () {
+                                pool.getCollection(model.get('folder_id')).sort();
+                                return newId;
+                            });
+                }
             },
             function fail(error) {
                 //get fresh data for the model (the current ones are wrong since we applied the changes early to be responsive)
@@ -852,7 +904,8 @@ define('io.ox/core/folder/api', [
 
     function move(id, target, ignoreWarnings) {
 
-        if (id === target) return;
+        // doesn't make sense but let's silently finish
+        if (id === target) return $.when();
 
         // prepare move
         var model = pool.getModel(id),
@@ -866,24 +919,25 @@ define('io.ox/core/folder/api', [
         //set unread to 0 to update subtotal attributes of parent folders (bubbles through the tree)
         model.set('unread', 0);
 
-        return update(id, { folder_id: target }, { ignoreWarnings: ignoreWarnings }).then(function success(newId) {
-            // update new parent folder
-            pool.getModel(target).set('subfolders', true);
-            // update all virtual folders
-            virtual.refresh();
-            // add folder to collection
-            pool.getCollection(target).add(model);
-            // trigger event
-            api.trigger('move', id, newId);
-        }, function fail(error) {
-            // update new parent folder
-            pool.getModel(folderId).set('subfolders', true);
-            // update all virtual folders
-            virtual.refresh();
-            // add folder to collection
-            pool.getCollection(folderId).add(model);
-            return error;
-        });
+        return update(id, { folder_id: target }, { ignoreWarnings: ignoreWarnings }).then(
+            function success(newId) {
+                // update new parent folder
+                pool.getModel(target).set('subscr_subflds', true);
+                // update all virtual folders
+                virtual.refresh();
+                // add folder to collection
+                pool.getCollection(target).add(model);
+                // trigger event
+                api.trigger('move', id, newId);
+            },
+            function fail(error) {
+                // re-add folder
+                pool.getModel(folderId).set('subscr_subflds', true);
+                virtual.refresh();
+                pool.getCollection(folderId).add(model);
+                return error;
+            }
+        );
     }
 
     //
@@ -938,7 +992,7 @@ define('io.ox/core/folder/api', [
                 if (!blacklist.visible(data)) api.trigger('warn:hidden', data);
             })
             .done(function updateParentFolder(data) {
-                pool.getModel(id).set('subfolders', true);
+                pool.getModel(id).set('subscr_subflds', true);
                 virtual.refresh();
                 api.trigger('create', data);
                 api.trigger('create:' + id.replace(/\s/g, '_'), data);
@@ -987,6 +1041,10 @@ define('io.ox/core/folder/api', [
             api.trigger('remove', id, data);
             api.trigger('remove:' + id, data);
             api.trigger('remove:' + data.module, data);
+            if (account.is('trash', id)) {
+                // if this is a trash folder trigger special event (quota updates)
+                api.trigger('cleared-trash');
+            }
         })
         .fail(function () {
             api.trigger('remove:fail', id);
@@ -1011,6 +1069,10 @@ define('io.ox/core/folder/api', [
             data: [id]
         })
         .done(function () {
+            if (account.is('trash', id)) {
+                // if this is a trash folder trigger special event (quota updates)
+                api.trigger('cleared-trash');
+            }
             api.trigger('clear', id);
             refresh();
         });
@@ -1066,7 +1128,8 @@ define('io.ox/core/folder/api', [
     //
 
     function getFolderId(arg) {
-        return _.isString(arg) ? arg : (arg ? arg.folder_id : null);
+        if (_.isString(arg)) return arg;
+        return arg ? arg.folder_id : null;
     }
 
     function reload() {
@@ -1175,7 +1238,7 @@ define('io.ox/core/folder/api', [
     ox.on('please:refresh refresh^', refresh);
 
     // If there is a new filestorage refresh the folders
-    $(filestorageApi).on('create delete update', refresh);
+    filestorageApi.on('create delete update', refresh);
 
     //
     // Get standard mail folders
@@ -1212,9 +1275,9 @@ define('io.ox/core/folder/api', [
 
     function getExistingFolder(type) {
         var defaultId = util.getDefaultFolder(type);
-        if (defaultId) return defaultId;
-        if (type === 'mail') return 'default0' + mailSettings.get('defaultseparator') + 'INBOX';
-        if (type === 'infostore') return 10;
+        if (defaultId) return $.Deferred().resolve(defaultId);
+        if (type === 'mail') return $.Deferred().resolve('default0' + mailSettings.get('defaultseparator', '/') + 'INBOX');
+        if (type === 'infostore') return $.Deferred().resolve(10);
         return flat({ module: type }).then(function (data) {
             for (var section in data) {
                 if (section === 'hidden') continue;
