@@ -45,19 +45,18 @@ define('io.ox/core/folder/favorites', [
         api.virtual.add(id, function () {
             return api.multiple(settings.get('favorites/' + module, []), { errors: true }).then(function (response) {
                 // remove non-existent entries
-                var list = _(response).filter(function (item) {
+                var list = _(response).filter(function (item) {
                     // FLD-0008 -> not found
                     // FLD-0003 -> permission denied
                     if (item.error && (item.code === 'FLD-0008' || item.code === 'FLD-0003')) {
                         invalid[item.id] = true;
                         return false;
-                    } else {
-                        delete invalid[item.id];
-                        return true;
                     }
+                    delete invalid[item.id];
+                    return true;
                 });
                 _(list).each(api.injectIndex.bind(api, id));
-                model.set('subfolders', list.length > 0);
+                model.set('subscr_subflds', list.length > 0);
                 // if there was an error we update settings
                 if (list.length !== response.length) _.defer(storeCollection);
                 return list;
