@@ -45,6 +45,7 @@ define('io.ox/core/folder/picker', [
     //     settings     {object}    app-specific settings
     //     title        {string}    dialog title / can also be DOM element(s)
     //     width        {number}    dialog width in px
+    //     open         [array]     Folders to be open by default; array of IDs
     //
     //   Callbacks:
     //     always       {function}  Called on "ok" / no matter if a folder is selected
@@ -53,6 +54,7 @@ define('io.ox/core/folder/picker', [
     //     done         {function}  Called on "ok" (and a folder is selected)
     //     initialize   {function}  Called to have access to dialog and tree
     //     show         {function}  Called on show
+    //     cancel       {function]  Called on "cancel"
 
     return function (options) {
 
@@ -70,6 +72,7 @@ define('io.ox/core/folder/picker', [
             persistent: false,
             hideTrashfolder: false,
             root: '1',
+            open: [],
             selection: true,
             title: gt('Select folder'),
             width: 500,
@@ -84,7 +87,8 @@ define('io.ox/core/folder/picker', [
             initialize: $.noop,
             close: $.noop,
             show: $.noop,
-            alternative: $.noop
+            alternative: $.noop,
+            cancel: $.noop
         }, options);
 
         var dialog = new dialogs.ModalDialog({ async: o.async, addClass: o.addClass, width: o.width })
@@ -118,7 +122,7 @@ define('io.ox/core/folder/picker', [
             indent: o.indent,
             module: o.module,
             abs: o.abs,
-            open: ['1'].concat(open),
+            open: ['1'].concat(o.open, open),
             root: o.root,
             customize: o.customize,
             disable: o.disable,
@@ -160,6 +164,7 @@ define('io.ox/core/folder/picker', [
             .on('alternative', function () {
                 o.alternative(dialog, tree);
             })
+            .on('cancel', o.cancel)
             .show(function () {
                 dialog.getBody().busy();
                 (id ? api.path(id) : $.Deferred().reject())
