@@ -18,364 +18,366 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
 
     // default columns for each module
     var idMapping = {
-        'common': {
-            '1': 'id',
-            '2': 'created_by',
-            '3': 'modified_by',
-            '4': 'creation_date',
-            '5': 'last_modified',
-            '20': 'folder_id',
-            '100': 'categories',
-            '101': 'private_flag',
-            '102': 'color_label',
-            '104': 'number_of_attachments'
+            'common': {
+                '1': 'id',
+                '2': 'created_by',
+                '3': 'modified_by',
+                '4': 'creation_date',
+                '5': 'last_modified',
+                '20': 'folder_id',
+                '100': 'categories',
+                '101': 'private_flag',
+                '102': 'color_label',
+                '104': 'number_of_attachments'
+            },
+            'mail': {
+                '102': 'color_label',
+                '600': 'id',
+                '601': 'folder_id',
+                '602': 'attachment',
+                '603': 'from',
+                '604': 'to',
+                '605': 'cc',
+                '606': 'bcc',
+                '607': 'subject',
+                '608': 'size',
+                '609': 'sent_date',
+                '610': 'received_date',
+                '611': 'flags',
+                '612': 'level',
+                '613': 'disp_notification_to',
+                '614': 'priority',
+                '615': 'msgref',
+                '651': 'flag_seen',
+                '652': 'account_name',
+                '654': 'original_id',
+                '655': 'original_folder_id',
+                '656': 'content_type'
+            },
+            'contacts': {
+                '500': 'display_name',
+                '501': 'first_name',
+                '502': 'last_name',
+                '503': 'second_name',
+                '504': 'suffix',
+                '505': 'title',
+                '506': 'street_home',
+                '507': 'postal_code_home',
+                '508': 'city_home',
+                '509': 'state_home',
+                '510': 'country_home',
+                '511': 'birthday',
+                '512': 'marital_status',
+                '513': 'number_of_children',
+                '514': 'profession',
+                '515': 'nickname',
+                '516': 'spouse_name',
+                '517': 'anniversary',
+                '518': 'note',
+                '519': 'department',
+                '520': 'position',
+                '521': 'employee_type',
+                '522': 'room_number',
+                '523': 'street_business',
+                '524': 'internal_userid', // user_id
+                '525': 'postal_code_business',
+                '526': 'city_business',
+                '527': 'state_business',
+                '528': 'country_business',
+                '529': 'number_of_employees',
+                '530': 'sales_volume',
+                '531': 'tax_id',
+                '532': 'commercial_register',
+                '533': 'branches',
+                '534': 'business_category',
+                '535': 'info',
+                '536': 'manager_name',
+                '537': 'assistant_name',
+                '538': 'street_other',
+                '539': 'city_other',
+                '540': 'postal_code_other',
+                '541': 'country_other',
+                '542': 'telephone_business1',
+                '543': 'telephone_business2',
+                '544': 'fax_business',
+                '545': 'telephone_callback',
+                '546': 'telephone_car',
+                '547': 'telephone_company',
+                '548': 'telephone_home1',
+                '549': 'telephone_home2',
+                '550': 'fax_home',
+                '551': 'cellular_telephone1',
+                '552': 'cellular_telephone2',
+                '553': 'telephone_other',
+                '554': 'fax_other',
+                '555': 'email1',
+                '556': 'email2',
+                '557': 'email3',
+                '558': 'url',
+                '559': 'telephone_isdn',
+                '560': 'telephone_pager',
+                '561': 'telephone_primary',
+                '562': 'telephone_radio',
+                '563': 'telephone_telex',
+                '564': 'telephone_ttytdd',
+                '565': 'instant_messenger1',
+                '566': 'instant_messenger2',
+                '567': 'telephone_ip',
+                '568': 'telephone_assistant',
+                '569': 'company',
+                //'570': 'image1',
+                '571': 'userfield01',
+                '572': 'userfield02',
+                '573': 'userfield03',
+                '574': 'userfield04',
+                '575': 'userfield05',
+                '576': 'userfield06',
+                '577': 'userfield07',
+                '578': 'userfield08',
+                '579': 'userfield09',
+                '580': 'userfield10',
+                '581': 'userfield11',
+                '582': 'userfield12',
+                '583': 'userfield13',
+                '584': 'userfield14',
+                '585': 'userfield15',
+                '586': 'userfield16',
+                '587': 'userfield17',
+                '588': 'userfield18',
+                '589': 'userfield19',
+                '590': 'userfield20',
+                '592': 'distribution_list',
+                '594': 'number_of_distribution_list',
+                '596': 'contains_image1',
+                '597': 'image_last_modified',
+                '598': 'state_other',
+                '599': 'file_as',
+                '104': 'number_of_attachments',
+                '601': 'image1_content_type',
+                '602': 'mark_as_distributionlist',
+                '605': 'default_address',
+                '606': 'image1_url',
+                '607': 'sort_name',
+                '610': 'yomiFirstName',
+                '611': 'yomiLastName',
+                '612': 'yomiCompany'
+            },
+            'calendar': {
+                '200': 'title',
+                '201': 'start_date',
+                '202': 'end_date',
+                '203': 'note',
+                '204': 'alarm',
+                '206': 'recurrence_id',
+                '207': 'recurrence_position',
+                '208': 'recurrence_date_position',
+                '209': 'recurrence_type',
+                '210': 'change_exceptions',
+                '211': 'delete_exceptions',
+                '212': 'days',
+                '213': 'day_in_month',
+                '214': 'month',
+                '215': 'interval',
+                '216': 'until',
+                '217': 'notification',
+                '220': 'participants',
+                '221': 'users',
+                '222': 'occurrences',
+                '223': 'uid',
+                '224': 'organizer',
+                '225': 'sequence',
+                '226': 'confirmations',
+                '227': 'organizerId',
+                '228': 'principal',
+                '229': 'principalId',
+                '400': 'location',
+                '401': 'full_time',
+                '402': 'shown_as',
+                '408': 'timezone',
+                '410': 'recurrence_start'
+            },
+            'files': {
+                '23': 'meta',
+                '108': 'object_permissions',
+                '109': 'shareable',
+                '700': 'title',
+                '701': 'url',
+                '702': 'filename',
+                '703': 'file_mimetype',
+                '704': 'file_size',
+                '705': 'version',
+                '706': 'description',
+                '707': 'locked_until',
+                '708': 'file_md5sum',
+                '709': 'version_comment',
+                '710': 'current_version',
+                '711': 'number_of_versions',
+                '7010': 'com.openexchange.share.extendedObjectPermissions',
+                '7030': 'com.openexchange.file.storage.mail.mailMetadata',
+                '7040': 'com.openexchange.file.sanitizedFilename'
+            },
+            'tasks': {
+                '200': 'title',
+                '201': 'start_date',
+                '202': 'end_date',
+                '203': 'note',
+                '204': 'alarm',
+                '209': 'recurrence_type',
+                '212': 'days',
+                '213': 'day_in_month',
+                '214': 'month',
+                '215': 'internal',
+                '216': 'until',
+                '220': 'participants',
+                '221': 'users',
+                '300': 'status',
+                '301': 'percent_completed',
+                '302': 'actual_costs',
+                '303': 'actual_duration',
+                '305': 'billing_information',
+                '307': 'target_costs',
+                '308': 'target_duration',
+                '309': 'priority',
+                '312': 'currency',
+                '313': 'trip_meter',
+                '314': 'companies',
+                '315': 'date_completed',
+                '316': 'start_time',
+                '317': 'end_time',
+                '401': 'full_time'
+            },
+            'folders': {
+                '1': 'id',
+                '2': 'created_by',
+                '3': 'modified_by',
+                '4': 'creation_date',
+                '5': 'last_modified',
+                '6': 'last_modified_utc',
+                '20': 'folder_id',
+                '23': 'meta',
+                '300': 'title',
+                '301': 'module',
+                '302': 'type',
+                '304': 'subfolders',
+                '305': 'own_rights',
+                '306': 'permissions',
+                '307': 'summary',
+                '308': 'standard_folder',
+                '309': 'total',
+                '310': 'new',
+                '311': 'unread',
+                '312': 'deleted',
+                '313': 'capabilities',
+                '314': 'subscribed',
+                '315': 'subscr_subflds',
+                '316': 'standard_folder_type',
+                '317': 'supported_capabilities',
+                '318': 'account_id',
+                '3010': 'com.openexchange.publish.publicationFlag',
+                '3020': 'com.openexchange.subscribe.subscriptionFlag',
+                '3030': 'com.openexchange.folderstorage.displayName',
+                // 3040 exists; around EAS; no need for it
+                '3050': 'com.openexchange.imap.extAccount',
+                '3060': 'com.openexchange.share.extendedPermissions'
+            },
+            'user': {
+                '610': 'aliases',
+                '611': 'timezone',
+                '612': 'locale',
+                '613': 'groups',
+                '614': 'contact_id',
+                '615': 'login_info',
+                '616': 'guest_created_by'
+            },
+            'group': {
+                '1':   'id',
+                '700': 'name',
+                '701': 'display_name',
+                '702': 'members'
+            },
+            'resource': {
+            },
+            'account': {
+                '1001': 'id',
+                '1002': 'login',
+                '1003': 'password',
+                '1004': 'mail_url',
+                '1005': 'transport_url',
+                '1006': 'name',
+                '1007': 'primary_address',
+                '1008': 'spam_handler',
+                '1009': 'trash',
+                '1010': 'sent',
+                '1011': 'drafts',
+                '1012': 'spam',
+                '1013': 'confirmed_spam',
+                '1014': 'confirmed_ham',
+                '1015': 'mail_server',
+                '1016': 'mail_port',
+                '1017': 'mail_protocol',
+                '1018': 'mail_secure',
+                '1019': 'transport_server',
+                '1020': 'transport_port',
+                '1021': 'transport_protocol',
+                '1022': 'transport_secure',
+                '1023': 'transport_login',
+                '1024': 'transport_password',
+                '1025': 'unified_inbox_enabled',
+                '1026': 'trash_fullname',
+                '1027': 'sent_fullname',
+                '1028': 'drafts_fullname',
+                '1029': 'spam_fullname',
+                '1030': 'confirmed_spam_fullname',
+                '1031': 'confirmed_ham_fullname',
+                '1032': 'pop3_refresh_rate',
+                '1033': 'pop3_expunge_on_quit',
+                '1034': 'pop3_delete_write_through',
+                '1035': 'pop3_storage ',
+                '1036': 'pop3_path',
+                '1037': 'personal',
+                '1038': 'reply_to',
+                '1039': 'addresses',
+                '1040': 'meta',
+                '1041': 'archive',
+                '1042': 'archive_fullname',
+                '1043': 'transport_auth'
+            },
+            'attachment': {
+                '1': 'id',
+                '2': 'created_by',
+                '4': 'creation_date',
+                '800': 'folder',
+                '801': 'attached',
+                '802': 'module',
+                '803': 'filename',
+                '804': 'file_size',
+                '805': 'file_mimetype',
+                '806': 'rtf_flag'
+            },
+            'subscriptions': {
+                'id': 'id',
+                'folder': 'folder',
+                'source': 'source',
+                'displayName': 'displayName',
+                'enabled': 'enabled'
+            },
+            'publications': {
+                'id': 'id',
+                'entity': 'entity',
+                'entityModule': 'entityModule',
+                'target': 'target',
+                'enabled': 'enabled'
+            },
+            'subscriptionSources': {
+                'id': 'id',
+                'displayName': 'displayName',
+                'icon': 'icon',
+                'module': 'module',
+                'formDescription': 'formDescription'
+            }
         },
-        'mail': {
-            '102': 'color_label',
-            '600': 'id',
-            '601': 'folder_id',
-            '602': 'attachment',
-            '603': 'from',
-            '604': 'to',
-            '605': 'cc',
-            '606': 'bcc',
-            '607': 'subject',
-            '608': 'size',
-            '609': 'sent_date',
-            '610': 'received_date',
-            '611': 'flags',
-            '612': 'level',
-            '613': 'disp_notification_to',
-            '614': 'priority',
-            '615': 'msgref',
-            '651': 'flag_seen',
-            '652': 'account_name',
-            '654': 'original_folder_id',
-            '655': 'original_id',
-            '656': 'content_type'
-        },
-        'contacts': {
-            '500': 'display_name',
-            '501': 'first_name',
-            '502': 'last_name',
-            '503': 'second_name',
-            '504': 'suffix',
-            '505': 'title',
-            '506': 'street_home',
-            '507': 'postal_code_home',
-            '508': 'city_home',
-            '509': 'state_home',
-            '510': 'country_home',
-            '511': 'birthday',
-            '512': 'marital_status',
-            '513': 'number_of_children',
-            '514': 'profession',
-            '515': 'nickname',
-            '516': 'spouse_name',
-            '517': 'anniversary',
-            '518': 'note',
-            '519': 'department',
-            '520': 'position',
-            '521': 'employee_type',
-            '522': 'room_number',
-            '523': 'street_business',
-            '524': 'internal_userid', // user_id
-            '525': 'postal_code_business',
-            '526': 'city_business',
-            '527': 'state_business',
-            '528': 'country_business',
-            '529': 'number_of_employees',
-            '530': 'sales_volume',
-            '531': 'tax_id',
-            '532': 'commercial_register',
-            '533': 'branches',
-            '534': 'business_category',
-            '535': 'info',
-            '536': 'manager_name',
-            '537': 'assistant_name',
-            '538': 'street_other',
-            '539': 'city_other',
-            '540': 'postal_code_other',
-            '541': 'country_other',
-            '542': 'telephone_business1',
-            '543': 'telephone_business2',
-            '544': 'fax_business',
-            '545': 'telephone_callback',
-            '546': 'telephone_car',
-            '547': 'telephone_company',
-            '548': 'telephone_home1',
-            '549': 'telephone_home2',
-            '550': 'fax_home',
-            '551': 'cellular_telephone1',
-            '552': 'cellular_telephone2',
-            '553': 'telephone_other',
-            '554': 'fax_other',
-            '555': 'email1',
-            '556': 'email2',
-            '557': 'email3',
-            '558': 'url',
-            '559': 'telephone_isdn',
-            '560': 'telephone_pager',
-            '561': 'telephone_primary',
-            '562': 'telephone_radio',
-            '563': 'telephone_telex',
-            '564': 'telephone_ttytdd',
-            '565': 'instant_messenger1',
-            '566': 'instant_messenger2',
-            '567': 'telephone_ip',
-            '568': 'telephone_assistant',
-            '569': 'company',
-            //'570': 'image1',
-            '571': 'userfield01',
-            '572': 'userfield02',
-            '573': 'userfield03',
-            '574': 'userfield04',
-            '575': 'userfield05',
-            '576': 'userfield06',
-            '577': 'userfield07',
-            '578': 'userfield08',
-            '579': 'userfield09',
-            '580': 'userfield10',
-            '581': 'userfield11',
-            '582': 'userfield12',
-            '583': 'userfield13',
-            '584': 'userfield14',
-            '585': 'userfield15',
-            '586': 'userfield16',
-            '587': 'userfield17',
-            '588': 'userfield18',
-            '589': 'userfield19',
-            '590': 'userfield20',
-            '592': 'distribution_list',
-            '594': 'number_of_distribution_list',
-            '596': 'contains_image1',
-            '597': 'image_last_modified',
-            '598': 'state_other',
-            '599': 'file_as',
-            '104': 'number_of_attachments',
-            '601': 'image1_content_type',
-            '602': 'mark_as_distributionlist',
-            '605': 'default_address',
-            '606': 'image1_url',
-            '607': 'sort_name',
-            '610': 'yomiFirstName',
-            '611': 'yomiLastName',
-            '612': 'yomiCompany'
-        },
-        'calendar': {
-            '200': 'title',
-            '201': 'start_date',
-            '202': 'end_date',
-            '203': 'note',
-            '204': 'alarm',
-            '206': 'recurrence_id',
-            '207': 'recurrence_position',
-            '208': 'recurrence_date_position',
-            '209': 'recurrence_type',
-            '210': 'change_exceptions',
-            '211': 'delete_exceptions',
-            '212': 'days',
-            '213': 'day_in_month',
-            '214': 'month',
-            '215': 'interval',
-            '216': 'until',
-            '217': 'notification',
-            '220': 'participants',
-            '221': 'users',
-            '222': 'occurrences',
-            '223': 'uid',
-            '224': 'organizer',
-            '225': 'sequence',
-            '226': 'confirmations',
-            '227': 'organizerId',
-            '228': 'principal',
-            '229': 'principalId',
-            '400': 'location',
-            '401': 'full_time',
-            '402': 'shown_as',
-            '408': 'timezone',
-            '410': 'recurrence_start'
-        },
-        'files': {
-            '23': 'meta',
-            '108': 'object_permissions',
-            '109': 'shareable',
-            '700': 'title',
-            '701': 'url',
-            '702': 'filename',
-            '703': 'file_mimetype',
-            '704': 'file_size',
-            '705': 'version',
-            '706': 'description',
-            '707': 'locked_until',
-            '708': 'file_md5sum',
-            '709': 'version_comment',
-            '710': 'current_version',
-            '711': 'number_of_versions',
-            '7010': 'com.openexchange.share.extendedObjectPermissions'
-        },
-        'tasks': {
-            '200': 'title',
-            '201': 'start_date',
-            '202': 'end_date',
-            '203': 'note',
-            '204': 'alarm',
-            '209': 'recurrence_type',
-            '212': 'days',
-            '213': 'day_in_month',
-            '214': 'month',
-            '215': 'internal',
-            '216': 'until',
-            '220': 'participants',
-            '221': 'users',
-            '300': 'status',
-            '301': 'percent_completed',
-            '302': 'actual_costs',
-            '303': 'actual_duration',
-            '305': 'billing_information',
-            '307': 'target_costs',
-            '308': 'target_duration',
-            '309': 'priority',
-            '312': 'currency',
-            '313': 'trip_meter',
-            '314': 'companies',
-            '315': 'date_completed',
-            '316': 'start_time',
-            '317': 'end_time',
-            '401': 'full_time'
-        },
-        'folders': {
-            '1': 'id',
-            '2': 'created_by',
-            '3': 'modified_by',
-            '4': 'creation_date',
-            '5': 'last_modified',
-            '6': 'last_modified_utc',
-            '20': 'folder_id',
-            '23': 'meta',
-            '300': 'title',
-            '301': 'module',
-            '302': 'type',
-            '304': 'subfolders',
-            '305': 'own_rights',
-            '306': 'permissions',
-            '307': 'summary',
-            '308': 'standard_folder',
-            '309': 'total',
-            '310': 'new',
-            '311': 'unread',
-            '312': 'deleted',
-            '313': 'capabilities',
-            '314': 'subscribed',
-            '315': 'subscr_subflds',
-            '316': 'standard_folder_type',
-            '317': 'supported_capabilities',
-            '318': 'account_id',
-            '3010': 'com.openexchange.publish.publicationFlag',
-            '3020': 'com.openexchange.subscribe.subscriptionFlag',
-            '3030': 'com.openexchange.folderstorage.displayName',
-            // 3040 exists; around EAS; no need for it
-            '3050': 'com.openexchange.imap.extAccount',
-            '3060': 'com.openexchange.share.extendedPermissions'
-        },
-        'user': {
-            '610': 'aliases',
-            '611': 'timezone',
-            '612': 'locale',
-            '613': 'groups',
-            '614': 'contact_id',
-            '615': 'login_info',
-            '616': 'guest_created_by'
-        },
-        'group': {
-            '1':   'id',
-            '700': 'name',
-            '701': 'display_name',
-            '702': 'members'
-        },
-        'resource': {
-        },
-        'account': {
-            '1001': 'id',
-            '1002': 'login',
-            '1003': 'password',
-            '1004': 'mail_url',
-            '1005': 'transport_url',
-            '1006': 'name',
-            '1007': 'primary_address',
-            '1008': 'spam_handler',
-            '1009': 'trash',
-            '1010': 'sent',
-            '1011': 'drafts',
-            '1012': 'spam',
-            '1013': 'confirmed_spam',
-            '1014': 'confirmed_ham',
-            '1015': 'mail_server',
-            '1016': 'mail_port',
-            '1017': 'mail_protocol',
-            '1018': 'mail_secure',
-            '1019': 'transport_server',
-            '1020': 'transport_port',
-            '1021': 'transport_protocol',
-            '1022': 'transport_secure',
-            '1023': 'transport_login',
-            '1024': 'transport_password',
-            '1025': 'unified_inbox_enabled',
-            '1026': 'trash_fullname',
-            '1027': 'sent_fullname',
-            '1028': 'drafts_fullname',
-            '1029': 'spam_fullname',
-            '1030': 'confirmed_spam_fullname',
-            '1031': 'confirmed_ham_fullname',
-            '1032': 'pop3_refresh_rate',
-            '1033': 'pop3_expunge_on_quit',
-            '1034': 'pop3_delete_write_through',
-            '1035': 'pop3_storage ',
-            '1036': 'pop3_path',
-            '1037': 'personal',
-            '1038': 'reply_to',
-            '1039': 'addresses',
-            '1040': 'meta',
-            '1041': 'archive',
-            '1042': 'archive_fullname',
-            '1043': 'transport_auth'
-        },
-        'attachment': {
-            '1': 'id',
-            '2': 'created_by',
-            '4': 'creation_date',
-            '800': 'folder',
-            '801': 'attached',
-            '802': 'module',
-            '803': 'filename',
-            '804': 'file_size',
-            '805': 'file_mimetype',
-            '806': 'rtf_flag'
-        },
-        'subscriptions': {
-            'id': 'id',
-            'folder': 'folder',
-            'source': 'source',
-            'displayName': 'displayName',
-            'enabled': 'enabled'
-        },
-        'publications': {
-            'id': 'id',
-            'entity': 'entity',
-            'entityModule': 'entityModule',
-            'target': 'target',
-            'enabled': 'enabled'
-        },
-        'subscriptionSources': {
-            'id': 'id',
-            'displayName': 'displayName',
-            'icon': 'icon',
-            'module': 'module',
-            'formDescription': 'formDescription'
-        }
-    },
-    // extended permissions
-    idMappingExcludes = ['3060', '7010'];
+        // extended permissions
+        idMappingExcludes = ['3060', '7010'];
 
     // extend with commons (not all modules use common columns, e.g. folders)
     $.extend(idMapping.contacts, idMapping.common);
@@ -391,6 +393,8 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
     var that = {};
 
     var isLoss = function (status) {
+        // 400 is Bad Request which usually is a missing parameter
+        if (status === 400) return false;
         return (/^(0|4\d\d|5\d\d)$/).test(status);
     };
 
@@ -488,8 +492,9 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
         // flatten this array
         var tmp = [], column = '';
         for (column in ids) {
-            if ( idMappingExcludes.indexOf(column) === -1 )
+            if (idMappingExcludes.indexOf(column) === -1) {
                 tmp.push(column);
+            }
         }
         tmp.sort(function (a, b) {
             return a - b;
@@ -531,7 +536,7 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 params: {},
                 data: {},
                 dataType: 'json',
-                appendColumns: type === 'GET' || type === 'UPLOAD' ? false : true,
+                appendColumns: !(type === 'GET' || type === 'UPLOAD'), // GET and UPLOAD don't need columns
                 columnModule: options.module || '',
                 appendSession: true,
                 processData: true,
@@ -557,8 +562,10 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
         }
         // remove white space from columns (otherwise evil to debug)
         if (o.params.columns) {
-            o.params.columns.replace(/\s/g, '');
+            o.params.columns = o.params.columns.replace(/\s/g, '');
         }
+        // publish request before a potential use of JSON.stringify that omits undefined values
+        ox.trigger('http:before:send', o);
         // data & body
         if (type === 'GET' || type === 'POST') {
             // GET & POST
@@ -585,16 +592,15 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
         if (!_.isArray(data) || !columns) {
             // typically from "action=get" (already sanitized)
             return data;
-        } else {
-            // POST/PUT - sanitize data
-            var i = 0, $l = data.length, sanitized = [], obj,
-                columnList = columns.split(',');
-            for (; i < $l; i++) {
-                obj = data[i];
-                sanitized.push(_.isArray(obj) ? makeObject(obj, module, columnList) : obj);
-            }
-            return sanitized;
         }
+        // POST/PUT - sanitize data
+        var i = 0, $l = data.length, sanitized = [], obj,
+            columnList = columns.split(',');
+        for (; i < $l; i++) {
+            obj = data[i];
+            sanitized.push(_.isArray(obj) ? makeObject(obj, module, columnList) : obj);
+        }
+        return sanitized;
     };
 
     var processResponse = function (deferred, response, o) {
@@ -621,11 +627,10 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 ox.session = '';
                 ox.trigger('relogin:required', o, deferred, response);
                 return;
-            } else {
-                // genereal error
-                deferred.reject(response);
-                return;
             }
+            // genereal error
+            deferred.reject(response);
+            return;
         }
 
         if (isWarning) {
@@ -745,7 +750,6 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
             }
 
             var t0, ajax;
-
             t0 = _.now();
             ajax = $.ajax(ajaxOptions);
 
@@ -787,9 +791,8 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                     // Extract the JSON text
                     var matches = /\((\{.*?\})\)/.exec(response);
                     return matches && matches[1] ? JSON.parse(matches[1]) : JSON.parse(response);
-                } else {
-                    return response;
                 }
+                return response;
             })
             .done(function (response) {
 
@@ -797,8 +800,9 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 ox.trigger('connection:online connection:up');
 
                 //write response to console
-                if (ox.debug)
+                if (ox.debug) {
                     extract(r.o, response);
+                }
 
                 // slow?
                 var took = _.now() - t0;
@@ -882,7 +886,7 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
             if (r.o.type === 'GET' || r.o.type === 'PUT') {
 
                 // get hash value - we just use stringify here (xhr contains payload for unique PUT requests)
-                try { hash = JSON.stringify(r.xhr); } catch (e) {}
+                try { hash = JSON.stringify(r.xhr); } catch (e) { if (ox.debug) console.error(e); }
 
                 if (r.o.consolidate !== false && hash && _.isArray(requests[hash])) {
                     // enqueue callbacks
@@ -917,6 +921,7 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
         }
 
         return function (o, type) {
+
             // process options
             o = processOptions(o, type);
 
@@ -1234,6 +1239,10 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
             this.trigger('paused');
         },
 
+        isPaused: function () {
+            return paused;
+        },
+
         /**
          * Resume HTTP API. Send all queued requests as one multiple
          */
@@ -1305,6 +1314,12 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
             return def;
         },
 
+        getColumn: function (module, column) {
+            if (!module) return idMapping;
+            var columns = idMapping[module] || {};
+            return column ? columns[column] : columns;
+        },
+
         // send server ping
         ping: function () {
             var t0 = _.now();
