@@ -16,8 +16,9 @@
 
 define('io.ox/core/pdf/pdftextlayerbuilder', [
     'io.ox/core/pdf/pdfpolyfill',
+    'io.ox/core/pdf/pdfcustomstyle',
     '3rd.party/pdfjs/pdf.combined'
-], function (Polyfill, PDFJS) {
+], function (Polyfill, CustomStyle, PDFJS) {
     'use strict';
 
     /*
@@ -26,59 +27,6 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
      * SCROLLBAR_PADDING = 40; var VERTICAL_PADDING = 5;
      */
 
-    // optimised CSS custom property getter/setter
-    var CustomStyle = (function CustomStyleClosure() {
-
-        // As noted on: http://www.zachstronaut.com/posts/2009/02/17/
-        // animate-css-transforms-firefox-webkit.html
-        // in some versions of IE9 it is critical that ms appear in this
-        // list
-        // before Moz
-        var prefixes = ['ms', 'Moz', 'Webkit', 'O'];
-        var _cache = {};
-
-        function CustomStyle() {
-        }
-
-        CustomStyle.getProp = function get(propName, element) {
-            // check cache only when no element is given
-            if (arguments.length === 1 && typeof _cache[propName] === 'string') {
-                return _cache[propName];
-            }
-
-            element = element || document.documentElement;
-            var style = element.style, prefixed, uPropName;
-
-            // test standard property first
-            if (typeof style[propName] === 'string') {
-                return (_cache[propName] = propName);
-            }
-
-            // capitalize
-            uPropName = propName.charAt(0).toUpperCase() + propName.slice(1);
-
-            // test vendor specific properties
-            for (var i = 0, l = prefixes.length; i < l; i++) {
-                prefixed = prefixes[i] + uPropName;
-                if (typeof style[prefixed] === 'string') {
-                    return (_cache[propName] = prefixed);
-                }
-            }
-
-            // if all fails then set to undefined
-            return (_cache[propName] = 'undefined');
-        };
-
-        CustomStyle.setProp = function set(propName, element, str) {
-            var prop = this.getProp(propName);
-            if (prop !== 'undefined') {
-                element.style[prop] = str;
-            }
-        };
-
-        return CustomStyle;
-    })();
-
     /*
      * TODO (KA) rmeove? function getFileName(url) { var anchor =
      * url.indexOf('#'); var query = url.indexOf('?'); var end =
@@ -305,9 +253,9 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
 
                 var event = document.createEvent('CustomEvent');
                 event.initCustomEvent('textlayerrendered', true, true,
-                        {
-                            pageNumber: this.pageNumber
-                        });
+                    {
+                        pageNumber: this.pageNumber
+                    });
                 this.textLayerDiv.dispatchEvent(event);
             },
 
