@@ -40,9 +40,10 @@ define('io.ox/core/print', [
             try {
                 var selector = options.selector || 'script',
                     template = $(document.body).find('[type="text/template"]').filter(selector).html(),
-                    title = (options.title  || '').trim();
+                    title = (options.title || '').trim();
 
-                $(document.body).html(_.template(template)(it));
+                // edge has problems if the content is not trimmed and there is more than one node. So trim and put a wrapper around it.
+                $(document.body).html('<div class="print-wrapper">' + $.trim(_.template(template)(it)) + '</div>');
                 //hint: in case title contains a '.' chrome will cut off at this char when suggesting a filename
                 document.title = escapeTitle(ox.serverConfig.pageTitle) + escapeTitle(title.length ? ' ' + title : '') + ' ' + gt('Printout');
             } catch (e) {
@@ -55,7 +56,7 @@ define('io.ox/core/print', [
 
     function removeCallbacks() {
         for (var id in callbacks) {
-            if (callbacks[id].closed) {
+            if (callbacks[id] && callbacks[id].closed) {
                 delete callbacks[id];
                 delete window[id];
             }
