@@ -101,8 +101,9 @@ define('io.ox/core/tk/dropdown-options', [
                 //store in node
                 $anchor.data(_.extend($anchor.data(), { options: data }));
                 //store setting
-                if (opt.settings)
+                if (opt.settings) {
                     opt.settings.set('options/' + opt.id, data).save();
+                }
             },
 
             toggleValue = function (item) {
@@ -188,7 +189,7 @@ define('io.ox/core/tk/dropdown-options', [
                      nodes[item.name] = $('<li>').append($('<a href="#">')
                         .attr({ tabindex: $anchor.attr('tabindex') })
                         .append(
-                            $('<i class="fa fa-fw">'),
+                            $('<i class="fa fa-fw" aria-hidden="true">'),
                             $.txt(item.label)
                         )
                         .on('click', function (e) {
