@@ -43,7 +43,10 @@ define('io.ox/core/tk/list-control', ['io.ox/core/tk/list', 'io.ox/core/extensio
                 max = getLimit(ListViewControl.maxWidth, total),
                 app = this.listView.app,
                 width;
-
+            // there is no right side so there is no need to resize, causes strange behavior, see Bug 38186
+            if (right.length === 0) {
+                return;
+            }
             $(document).on({
                 'mousemove.resize': function (e) {
                     width = Math.max(min, Math.min(e.pageX - base, max));
@@ -51,7 +54,10 @@ define('io.ox/core/tk/list-control', ['io.ox/core/tk/list', 'io.ox/core/extensio
                     right.css('left', width);
                 },
                 'mouseup.resize': function () {
-                    $(this).off('mousemove.resize mouseup.resize');
+                    $(this)
+                        .off('mousemove.resize mouseup.resize')
+                        // trigger generic resize event so that other components can respond to it
+                        .trigger('resize');
                     storeSize(app, width, 'width');
                 }
             });
@@ -67,6 +73,10 @@ define('io.ox/core/tk/list-control', ['io.ox/core/tk/list', 'io.ox/core/extensio
                 max = getLimit(ListViewControl.maxHeight, total),
                 app = this.listView.app,
                 height;
+            // there is no right side so there is no need to resize, causes strange behavior, see Bug 38186
+            if (right.length === 0) {
+                return;
+            }
             $(document).on({
                 'mousemove.resize': function (e) {
                     height = Math.max(min, Math.min(e.pageY - base, max));
@@ -106,7 +116,7 @@ define('io.ox/core/tk/list-control', ['io.ox/core/tk/list', 'io.ox/core/extensio
                 topPoint.invoke('draw', top, baton);
             }
 
-            if (bottomPoint.list().length) {
+            if (bottomPoint.list().length && _.device('!smartphone')) {
                 this.$el.addClass('toolbar-bottom-visible');
                 bottomPoint.invoke('draw', bottom, baton);
             }
