@@ -67,6 +67,15 @@ define('io.ox/core/viewer/main', [], function () {
                     }
                     // create main view and append main view to core
                     self.mainView = new MainView({ collection: self.fileCollection, el: el, app: data.app, standalone: data.standalone, opt: data.opt || {} });
+
+                    self.mainView.on('dispose', function () {
+                        // remove id form URL hash (see bug 43410)
+                        // use-case: viewer was opened via deep-link; a page-reload might surprise the user
+                        // but don't remove the id from an OX Presenter URL
+                        if (_.url.hash('app') !== 'io.ox/presenter') {
+                            _.url.hash('id', null);
+                        }
+                    });
                 });
             }
 
@@ -74,7 +83,12 @@ define('io.ox/core/viewer/main', [], function () {
                 require(['io.ox/files/api'], function (api) {
                     api.getAll(data.folder).then(function success(files) {
                         data.selection = data.files[0];
-                        fileList = files;
+                        function getter(item) {
+                            return this.get(_.cid(item));
+                        }
+                        // the viewer has listeners that work directly on the model
+                        // so we need to get the pool models instead of creating own models
+                        fileList = _(files).map(getter, api.pool.get('detail'));
                     }).always(cont);
                 });
             } else {
