@@ -156,7 +156,7 @@ define('io.ox/core/viewer/views/mainview', [
                         isDropdownMenuItem = escTarget.parents('.dropdown-menu').length > 0,
                         isDropdownToggler = escTarget.attr('data-toggle') === 'dropdown';
                     // close the viewer only if user is not on a dropdown menu, or a dropdown menu item
-                    if ( !isDropdownMenuItem && !isDropdownToggler ) {
+                    if (!isDropdownMenuItem && !isDropdownToggler) {
                         this.closeViewer();
                     }
                     break;
@@ -176,6 +176,13 @@ define('io.ox/core/viewer/views/mainview', [
                     event.preventDefault();
                     this.viewerEvents.trigger('viewer:document:next');
                     break;
+                case 114: // Ctrl/Meta + F3
+                    if (!event.altKey && !event.shiftKey && (event.metaKey !== event.ctrlKey)) {
+                        event.preventDefault();
+                        this.onToggleSidebar();
+                    }
+                    break;
+                // no default
             }
         },
 
