@@ -9,7 +9,7 @@
  *
  * @author Mario Schroeder <mario.schroeder@open-xchange.com>
  */
-define('io.ox/core/viewer/views/types/videoview',  [
+define('io.ox/core/viewer/views/types/videoview', [
     'io.ox/core/viewer/views/types/baseview',
     'gettext!io.ox/core'
 ], function (BaseView, gt) {
@@ -79,7 +79,9 @@ define('io.ox/core/viewer/views/types/videoview',  [
             this.$el.idle().find('.viewer-displayer-video').addClass('player-hidden');
             this.$el.find('div.viewer-displayer-notification').remove();
             this.$el.append(
-                this.createNotificationNode(gt('Your browser does not support the video format of this file.'))
+                this.createNotificationNode(
+                    gt('Error while playing the video. Either your browser does not support the format or you have connection problems.')
+                )
             );
         },
 
