@@ -14,18 +14,24 @@
 define('io.ox/files/actions/move-copy', [
     'io.ox/files/api',
     'io.ox/core/folder/actions/move',
+    'io.ox/core/capabilities',
     'settings!io.ox/files'
-], function (api, move, settings) {
+], function (api, move, capabilities, settings) {
 
     'use strict';
 
     return function (list, baton, options) {
+
+        // auto-open folder 10 for guests (see bug 42621)
+        if (capabilities.has('guest')) options.open = ['10'];
+
         move.item({
             api: api,
             button: options.label,
             list: list,
             module: 'infostore',
             root: '9',
+            open: options.open,
             settings: settings,
             success: options.success,
             successCallback: options.successCallback,
