@@ -22,6 +22,16 @@ define('io.ox/files/common-extensions', [
 
     var extensions = {
 
+        ariaLabel: function (baton) {
+            var parts = [];
+            // filename, last modified, and size
+            parts.push(baton.data.filename || baton.data.title);
+            if (baton.model.isFolder()) parts.push(gt('Folder'));
+            parts.push(gt('modified') + ' ' + moment(baton.data.last_modified).format('LLL'));
+            parts.push(gt('size') + ' ' + strings.fileSize(baton.data.file_size || 0, 1));
+            this.attr('aria-label', parts.join(', ') + '.');
+        },
+
         date: function (baton, options) {
             var data = baton.data, t = data.last_modified;
             if (!_.isNumber(t)) return;
@@ -45,7 +55,7 @@ define('io.ox/files/common-extensions', [
         },
 
         filename: function (baton, ellipsis) {
-            var name = baton.data.filename || baton.data.title;
+            var name = baton.data['com.openexchange.file.sanitizedFilename'] || baton.data.filename || baton.data.title;
             // add suffix for locked files
             if (baton.model.isLocked()) name += ' (' + gt('Locked') + ')';
             // fix long names
@@ -71,7 +81,7 @@ define('io.ox/files/common-extensions', [
         },
 
         fileTypeIcon: function () {
-            this.append('<i class="fa file-type-icon">');
+            this.append('<i class="fa file-type-icon" aria-hidden="true">');
         },
 
         fileTypeClass: function (baton) {
@@ -115,7 +125,7 @@ define('io.ox/files/common-extensions', [
             function error() {
                 //fallback to default
                 $(this).parent().addClass('default-icon').append(
-                    $('<span class="file-icon"><i class="fa file-type-icon"></i></span>')
+                    $('<span class="file-icon"><i class="fa file-type-icon" aria-hidden="true"></i></span>')
                 );
                 $(this).remove();
             }
@@ -129,7 +139,7 @@ define('io.ox/files/common-extensions', [
                     return this.append(
                         $('<div class="icon-thumbnail default-icon">').append(
                             $('<span class="folder-name">').text(baton.model.getDisplayName()),
-                            $('<span class="folder-icon"><i class="fa file-type-icon"></i></span>')
+                            $('<span class="folder-icon"><i class="fa file-type-icon" aria-hidden="true"></i></span>')
                         )
                     );
                 }
@@ -164,7 +174,7 @@ define('io.ox/files/common-extensions', [
                 //
                 this.append(
                     $('<div class="icon-thumbnail default-icon">').append(
-                        $('<span class="file-icon"><i class="fa file-type-icon"></i></span>')
+                        $('<span class="file-icon"><i class="fa file-type-icon" aria-hidden="true"></i></span>')
                     )
                 );
             };
