@@ -43,7 +43,10 @@ define('io.ox/files/filepicker', [
             tree: {
                 // must be noop (must return undefined!)
                 filter: $.noop
-            }
+            },
+            acceptLocalFileType: '', //e.g.  '.jpg,.png,.doc', 'audio/*', 'image/*' see@ https://developer.mozilla.org/de/docs/Web/HTML/Element/Input#attr-accept
+            cancel: $.noop,
+            initialize: $.noop
         }, options);
 
         var filesPane = $('<ul class="io-ox-fileselection list-unstyled">'),
@@ -101,6 +104,16 @@ define('io.ox/files/filepicker', [
             options.uploadButton = false;
         }
 
+        function toggleOkButton(state) {
+            $('[data-action="ok"]', filesPane.closest('.add-infostore-file')).prop('disabled', !state);
+        }
+
+        toggleOkButton(false);
+
+        this.selection.on('change', function (e, list) {
+            toggleOkButton(list.length > 0);
+        });
+
         function onFolderChange(id) {
 
             if (currentFolder === id) {
@@ -120,6 +133,10 @@ define('io.ox/files/filepicker', [
                     pages.getNavbar('fileList').setTitle(gt('Files'));
                 });
             }
+
+            // disable ok button on folder change (selection will enable it)
+            toggleOkButton(false);
+
             filesPane.empty();
             filesAPI.getAll(id, { cache: false }).done(function (files) {
                 filesPane.append(
@@ -127,10 +144,9 @@ define('io.ox/files/filepicker', [
                     .filter(options.filter)
                     .sortBy(options.sorter)
                     .map(function (file) {
-                        var title = (file.filename || file.title),
+                        var title = (file['com.openexchange.file.sanitizedFilename'] || file.filename || file.title),
                             $div = $('<li class="file selectable">').attr('data-obj-id', _.cid(file)).append(
-                                $('<label class="">')
-                                    .addClass('checkbox-inline' + (!options.multiselect ? ' sr-only' : ''))
+                                $('<label class="checkbox-inline sr-only">')
                                     .attr('title', title)
                                     .append(
                                         $('<input type="checkbox" class="reflect-selection" tabindex="-1">')
@@ -242,6 +258,7 @@ define('io.ox/files/filepicker', [
                 if (options.uploadButton) {
                     $uploadButton = $('<input name="file" type="file" class="file-input">')
                         .attr('multiple', options.multiselect)
+                        .attr('accept', options.acceptLocalFileType)
                         .hide()
                         .on('change', { dialog: dialog, tree: tree }, fileUploadHandler);
                 }
@@ -274,6 +291,7 @@ define('io.ox/files/filepicker', [
                 }
 
                 tree.on('change', onFolderChange);
+                options.initialize(dialog);
             },
 
             alternative: function (dialog) {
@@ -281,7 +299,8 @@ define('io.ox/files/filepicker', [
                 if ($uploadButton) {
                     $uploadButton.trigger('click');
                 }
-            }
+            },
+            cancel: options.cancel
         });
 
         return def.promise();
