@@ -36,6 +36,11 @@ define('io.ox/files/share/api', [
             return !this.has('folder_id');
         },
 
+        getFolderModel: function () {
+            var id = this.isFile() ? this.get('folder_id') : this.get('id');
+            return folderAPI.pool.getModel(id);
+        },
+
         isAdmin: function () {
             // for files we don't have the parent folder information
             // use shareable attribute instead
@@ -60,7 +65,7 @@ define('io.ox/files/share/api', [
         },
 
         getDisplayName: function () {
-            return this.get('filename') || this.get('title') || '';
+            return this.get('com.openexchange.file.sanitizedFilename') || this.get('filename') || this.get('title') || '';
         },
 
         getFolderID: function () {
@@ -79,9 +84,8 @@ define('io.ox/files/share/api', [
         getPermissions: function () {
             if (this.isFolder()) {
                 return this.get('com.openexchange.share.extendedPermissions') || this.get('permissions');
-            } else {
-                return this.get('com.openexchange.share.extendedObjectPermissions') || this.get('object_permissions');
             }
+            return this.get('com.openexchange.share.extendedObjectPermissions') || this.get('object_permissions');
         },
 
         loadExtendedPermissions: (function () {
@@ -351,7 +355,7 @@ define('io.ox/files/share/api', [
          */
         remove: function (shares) {
             if (_.isString(shares)) {
-                shares = [ shares ];
+                shares = [shares];
             }
             return http.PUT({
                 module: 'share/management',
@@ -371,10 +375,9 @@ define('io.ox/files/share/api', [
                 collection.reset(_(model.getPermissions()).where({ entity: ox.user_id }));
                 changes = { permissions: collection.toJSON() };
                 return folderAPI.update(model.get('id'), changes);
-            } else {
-                changes = { object_permissions: [], 'com.openexchange.share.extendedObjectPermissions': [] };
-                return filesAPI.update(model.pick('folder_id', 'id'), changes);
             }
+            changes = { object_permissions: [], 'com.openexchange.share.extendedObjectPermissions': [] };
+            return filesAPI.update(model.pick('folder_id', 'id'), changes);
         },
 
         // resend invitation/notification
