@@ -40,12 +40,28 @@ define('io.ox/files/share/model', [
             };
         },
 
-        initialize: function (option) {
-            this.set('files', option.files);
-            this.set('type', option.type);
-            if (option.type === this.TYPES.INVITE) {
-                this.set('edit', true);
-            }
+        idAttribute: 'entity',
+
+        initialize: function (attributes) {
+            this.set('edit', attributes.type === this.TYPES.INVITE);
+            this.setOriginal();
+        },
+
+        setOriginal: function (data) {
+            this.originalAttributes = data || _.clone(this.attributes);
+        },
+
+        getChanges: function () {
+            var original = this.originalAttributes, changes = {};
+            _(this.attributes).each(function (val, id) {
+                if (!_.isEqual(val, original[id])) changes[id] = val;
+            });
+            // limit to relevant attributes
+            return _(changes).pick('expiry_date', 'password', 'temporary', 'secured');
+        },
+
+        hasChanges: function () {
+            return !_.isEmpty(this.getChanges());
         },
 
         getExpiryDate: function () {
@@ -129,6 +145,7 @@ define('io.ox/files/share/model', [
                             }
                             recipientData.email_address = recipientModel.get('token').value;
                             break;
+                        // no default
 
                     }
                     data.recipients.push(recipientData);
@@ -164,16 +181,14 @@ define('io.ox/files/share/model', [
                 }
 
                 // create or update ?
-                if (!this.has('url')) {
-                    return data;
+                if (!this.has('url')) return data;
+
+                if (this.get('temporary')) {
+                    data.expiry_date = this.getExpiryDate();
                 } else {
-                    if (this.get('temporary')) {
-                        data.expiry_date = this.getExpiryDate();
-                    } else {
-                        data.expiry_date = null;
-                    }
-                    return data;
+                    data.expiry_date = null;
                 }
+                return data;
             }
 
         },
@@ -188,24 +203,26 @@ define('io.ox/files/share/model', [
                     return api.invite(model.toJSON()).fail(yell);
                 case 'read':
                     return api.getLink(this.toJSON()).then(function (data, timestamp) {
-                        if (data.is_new === true) {
-                            // if existing link add unique ID to simulate existing Backbone model
-                            delete data.is_new;
-                            data.id = _.uniqueId();
-                        }
                         self.set(_.extend(data, { lastModified: timestamp }));
+                        self.setOriginal();
                         return data.url;
                     }).fail(yell);
-                case 'create':
                 case 'update':
-                    return api.updateLink(model.toJSON(), model.get('lastModified'))
+                case 'create':
+                    var changes = self.getChanges(),
+                        data = model.toJSON();
+                    // set password to null if password protection was revoked
+                    if (changes.secured === false) {
+                        data.password = null;
+                    } else if (!('password' in changes)) {
+                        // remove password from data unless it has changed
+                        delete data.password;
+                    }
+                    // update only if there are relevant changes
+                    return (_.isEmpty(changes) ? $.when() : api.updateLink(data, model.get('lastModified')))
                         .done(this.send.bind(this))
                         .fail(yell);
-                case 'delete':
-                    if (this.get('type') === this.TYPES.LINK) {
-                        return api.deleteLink(model.toJSON(), model.get('lastModified')).fail(yell);
-                    }
-                    break;
+                // no default
             }
         },
 
