@@ -11,20 +11,25 @@
  * @author Frank Paczynski <frank.paczynski@open-xchange.com>
  */
 
-define('io.ox/find/extensions-api',[
+define('io.ox/find/extensions-api', [
+    'io.ox/core/folder/util',
     'gettext!io.ox/core'
-], function (gt) {
+], function (folderUtil, gt) {
 
     'use strict';
 
-    function isVirtualFolder (data) {
+    function isVirtualFolder(data) {
         return /^virtual/.test(data.id);
     }
 
+    function isProtected(data) {
+        return !folderUtil.can('read', data);
+    }
+
     var extensions = {
 
         daterange: function (baton) {
-            if (_.device('smartphone') || (baton.app && baton.app.getModule() !== 'io.ox/mail') ) return;
+            if (_.device('smartphone') || (baton.app && baton.app.getModule() !== 'io.ox/mail')) return;
 
             var query = baton.request.data.prefix,
                 facet, value;
@@ -41,7 +46,7 @@ define('io.ox/find/extensions-api',[
                 facet = $.extend(facet, {
                     id: facet.id + '.custom',
                     style: 'custom',
-                    values: [ value ]
+                    values: [value]
                 });
                 // adjust value
                 delete value.filter;
@@ -69,15 +74,15 @@ define('io.ox/find/extensions-api',[
             if (_.device('smartphone')) return;
 
             var whitelist = {
-                    style: ['simple'],
-                    id: ['contacts', 'contact', 'participant', 'task_participants', 'date.custom']
-                };
+                style: ['simple'],
+                id: ['contacts', 'contact', 'participant', 'task_participants', 'date.custom']
+            };
 
             // flag  facet
             _.each(baton.data, function (facet) {
                 var style = _.contains(whitelist.style, facet.style),
                     id = _.contains(whitelist.id, facet.id),
-                    advanced = !(style || id);
+                    advanced = !(style || id);
 
                 // flag when not in whitelist
                 if (advanced) {
@@ -126,14 +131,14 @@ define('io.ox/find/extensions-api',[
                                     return folder.account_id === data.get('qualifiedId');
                                 });
                                 // get account name for current selected account and adjust name of 'all folders' option
-                                allfolders.item.name = allfolders.item.name +  ' (' + data.get('displayName') + ')';
+                                allfolders.item.name = allfolders.item.name + ' (' + data.get('displayName') + ')';
                             }
                             def.resolve(accounts, folders);
                         });
                     return def;
                 }
 
-                function compact (accounts, folders) {
+                function compact(accounts, folders) {
                     // store account data
                     _.each(accounts, function (account) {
                         accountdata[account.id] = account;
@@ -153,7 +158,7 @@ define('io.ox/find/extensions-api',[
                             .value();
                 }
 
-                function unify (list) {
+                function unify(list) {
                     // cluster folders into account hash
                     var accounts = {}, id;
                     _.each(list, function (item) {
@@ -165,7 +170,7 @@ define('io.ox/find/extensions-api',[
                     return accounts;
                 }
 
-                function cleanup (accounts) {
+                function cleanup(accounts) {
                     // handle account folders inplace: reduce, sort, hide
                     _.each(accounts, function (account, key) {
 
@@ -192,7 +197,7 @@ define('io.ox/find/extensions-api',[
                     return accounts;
                 }
 
-                function create (accounts) {
+                function create(accounts) {
                     // create facet/value/option structure
                     var options = folder.values[0].options;
 
@@ -244,34 +249,43 @@ define('io.ox/find/extensions-api',[
                     }
                 }
 
-                function preselect () {
+                function preselect() {
                     //preselect
                     var options = folder.values[0].options,
                         preselect, isMandatory, isDefault, isVirtual,
                         // possible preselected options
                         all = _.findWhere(options, { id: 'disabled' }),
                         selected = _.findWhere(options, { value: current }),
-                        standard = _.findWhere(options, { type: 'default' });
+                        standard = _.findWhere(options, { type: 'default' }),
+                        // primary check
+                        isSelectedPrimary = selected.account === '0';
 
                     // prefer selected before default folder
                     preselect = selected || standard;
 
+                    // preselect first valid standard folder in case invalid non-primary
+                    // folder was selected (account4711 -> account4711/INBOX)
+                    if (!isSelectedPrimary && selected && isProtected(selected.data)) {
+                        var account = selected.account;
+                        preselect = _.findWhere(options, { type: 'standard', account: account }) || preselect;
+                        // remove invalid entry from list
+                        if (preselect.id !== selected.id) {
+                            options = folder.values[0].options = _.without(options, selected);
+                        }
+                    }
+
                     // decision parameters
                     isMandatory = baton.app.isMandatory('folder');
                     isDefault = preselect.type === 'default';
                     isVirtual = module === 'mail' ? !folderAPI.can('read', preselect.data) : isVirtualFolder(preselect.data);
 
                     // conditions mapping
-                    if (!isMandatory) {
-                        if (isDefault || isVirtual) {
-                            // convenience function respectively fallback when virtual all not exists
-                            preselect = all || standard;
-                        }
-                    } else {
-                        if (isVirtual) {
-                            // fallback when folder is mandatory
-                            preselect = standard;
-                        }
+                    if (!isMandatory && (isDefault || isVirtual)) {
+                        // convenience function respectively fallback when virtual all not exists
+                        preselect = all || standard;
+                    } else if (isMandatory && isVirtual) {
+                        // fallback when folder is mandatory
+                        preselect = standard;
                     }
 
                     // flag as preselected
@@ -298,7 +312,7 @@ define('io.ox/find/extensions-api',[
                         item: {
                             name: gt('Folder')
                         },
-                        options: [ allfolders = {
+                        options: [allfolders = {
                             account: undefined,
                             value: null,
                             id: 'disabled',
@@ -323,11 +337,22 @@ define('io.ox/find/extensions-api',[
                 // standard folders for mail
                 if (module === 'mail') {
                     _.each(folderAPI.getStandardMailFolders(), function (id) {
-                        // use only primary here cause of the slow fetching folder data from externals accounts
                         var isPrimary = id.indexOf('default0') > -1,
-                            isValid = ['inbox', 'sent', 'drafts', 'trash'].indexOf(accountAPI.getType(id)) > -1;
-                        if (isPrimary && isValid)
-                            mapping[id] = 'standard';
+                            isValidPrimary = isPrimary && ['inbox', 'sent', 'drafts', 'trash'].indexOf(accountAPI.getType(id)) > -1;
+
+                        // primary-block
+                        if (isValidPrimary) return (mapping[id] = 'standard');
+                        if (isPrimary) return;
+
+                        // selected-non-primary block
+                        // hint: we are requesting only non-primary-account date when some folder is selected
+                        var selected = baton.app.get('parent').folder.get().split('/')[0];
+                        // same account?
+                        if (id.indexOf(selected) < 0) return;
+                        // valid type?
+                        if (['inbox', 'sent'].indexOf(accountAPI.getType(id)) < 0) return;
+
+                        return (mapping[id] = 'standard');
                     });
                     // add account data to multiple
                     req.push(accountAPI.all());
@@ -375,7 +400,7 @@ define('io.ox/find/extensions-api',[
             if (baton.app.getModuleParam() !== 'files') return def.resolve();
             var req = [];
 
-            function create () {
+            function create() {
                 // shorthand
                 var options = facet.values[0].options;
                 // for each filestorage type (e.g. dropbox)
@@ -396,20 +421,22 @@ define('io.ox/find/extensions-api',[
                             filter: null
                         };
                     // ensure primary is listed first
-                    if (isPrimary)
+                    if (isPrimary) {
                         options.splice(0, 0, option);
-                    else
+                    } else {
                         options.push(option);
+                    }
                 });
             }
 
-            function preselect () {
+            function preselect() {
                 // preselect account matching currently selected folder
                 return baton.app.get('parent').folder.getData()
                     .then(function (data) {
                         _.each(facet.values[0].options, function (option) {
-                            if (option.data.qualifiedId === data.account_id)
+                            if (option.data.qualifiedId === data.account_id) {
                                 option.active = true;
+                            }
                         });
                     });
             }
