@@ -11,23 +11,24 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/mail/actions/attachmentSave',
-    ['io.ox/mail/api',
-     'io.ox/core/notifications',
-     'io.ox/core/tk/dialogs',
-     'io.ox/core/folder/picker',
-     'io.ox/core/folder/api',
-     // yep, files not mail!
-     'settings!io.ox/files',
-     'settings!io.ox/core',
-     'gettext!io.ox/mail'], function (api, notifications, dialogs, picker, folderAPI, settings, settingsCore, gt) {
+define('io.ox/mail/actions/attachmentSave', [
+    'io.ox/mail/api',
+    'io.ox/core/notifications',
+    'io.ox/core/tk/dialogs',
+    'io.ox/core/folder/picker',
+    'io.ox/core/folder/api',
+    // yep, files not mail!
+    'settings!io.ox/files',
+    'settings!io.ox/core',
+    'gettext!io.ox/mail'
+], function (api, notifications, dialogs, picker, folderAPI, settings, settingsCore, gt) {
 
     'use strict';
 
     function commit(list, target) {
 
         notifications.yell('busy',
-            gt.ngettext('Saving attachment to Drive', 'Saving attachments to Drive', list.length) + ' ...'
+            gt.ngettext('Saving attachment ...', 'Saving attachments ...', list.length)
         );
 
         api.saveAttachments(list, target).then(
@@ -73,6 +74,7 @@ define('io.ox/mail/actions/attachmentSave',
                 root: '9',
                 settings: settings,
                 title: gt('Save attachment'),
+                hideTrashfolder: true,
 
                 done: function (target) {
                     commit(list, target);
