@@ -24,30 +24,36 @@ define('io.ox/mail/compose/inline-images', [
 
     var api = {
         inlineImage: function (data) {
-            if ('FormData' in window) {
-                var formData = new FormData();
-                formData.append('file', data.file);
-                return http.UPLOAD({
-                    module: 'file',
-                    params: { action: 'new', module: 'mail', type: 'image' },
-                    data: formData,
-                    fixPost: true
-                });
-            } else {
+            try {
+                if ('FormData' in window) {
+                    var formData = new FormData();
+                    formData.append('file', data.file);
+                    return http.UPLOAD({
+                        module: 'file',
+                        params: { action: 'new', module: 'mail', type: 'image' },
+                        data: formData,
+                        fixPost: true
+                    });
+                }
                 return http.FORM({
                     module: 'file',
                     form: data.form,
                     params: { module: 'mail', type: 'image' }
                 });
+            } catch (e) {
+                // print error to console for debugging
+                console.debug(e);
+                //#. generic erromessage if inserting an image into a mail failed.
+                return $.Deferred().reject({ error: e, message: gt('Error while uploading your image') });
             }
         },
         getInsertedImageUrl: function (data) {
             var url = ox.apiRoot + '/file',
-            url_params = $.param({
-                action: 'get',
-                id: data.data[0],
-                session: ox.session
-            });
+                url_params = $.param({
+                    action: 'get',
+                    id: data.data[0],
+                    session: ox.session
+                });
             return url + '?' + url_params;
         }
     };
@@ -84,7 +90,7 @@ define('io.ox/mail/compose/inline-images', [
     return {
         api: api,
         show: function () {
-            var noBusy = (_.browser.IE && _.browser.IE < 10),//IE9 upload fails if window becomes busy
+            var noBusy = (_.browser.IE && _.browser.IE < 10), // IE9 upload fails if window becomes busy
                 dialog = new dialogs.ModalDialog({ async: true, noBusy: noBusy }),
                 baton =  new ext.Baton({ $: {} }),
                 def = $.Deferred(),
