@@ -17,10 +17,9 @@ define.async('io.ox/mail/compose/model', [
     'io.ox/core/capabilities',
     'io.ox/core/api/account',
     'io.ox/core/attachments/backbone',
-    'io.ox/mail/compose/signatures',
     'settings!io.ox/mail',
     'gettext!io.ox/mail'
-], function (mailAPI, mailUtil, capabilities, accountAPI, Attachments, signatureUtil, settings, gt) {
+], function (mailAPI, mailUtil, capabilities, accountAPI, Attachments, settings, gt) {
 
     'use strict';
 
@@ -48,9 +47,7 @@ define.async('io.ox/mail/compose/model', [
                 priority: 3,
                 sendDisplayName: !!settings.get('sendDisplayName', true),
                 sendtype: mailAPI.SENDTYPE.NORMAL,
-                defaultSignatureId: settings.get('defaultSignature', ''),
-                // identifier for empty signature (dropdown)
-                signatureId: '',
+                defaultSignatureId: settings.get('defaultSignature'),
                 csid: mailAPI.csid(),
                 vcard: settings.get('appendVcard', false) ? 1 : 0,
                 infostore_ids_saved: []
@@ -58,7 +55,6 @@ define.async('io.ox/mail/compose/model', [
         },
 
         initialize: function () {
-            _.extend(this, signatureUtil.model, this);
             var self = this,
                 attachmentsCollection = this.get('attachments');
 
@@ -103,6 +99,7 @@ define.async('io.ox/mail/compose/model', [
                     this.set('editorMode', 'text', { silent: true });
                 }
             }
+
             if (!this.get('from') || this.get('from').length === 0) {
                 accountAPI.getPrimaryAddressFromFolder(this.get('folder_id')).then(function (address) {
                     // custom display names
@@ -113,6 +110,11 @@ define.async('io.ox/mail/compose/model', [
                 }.bind(this));
             }
 
+            // Set default signature dependant on mode, there are settings that correspond to this
+            if (this.get('mode') !== 'compose') {
+                this.set('defaultSignatureId', settings.get('defaultReplyForwardSignature'));
+            }
+
             this.set('autoDismiss', this.get('mode') === 'edit');
 
             if (!this.get('signatures')) this.set('signatures', this.getSignatures());
@@ -121,7 +123,7 @@ define.async('io.ox/mail/compose/model', [
         },
 
         getCopy: function () {
-            var ret = _.clone(this.attributes);
+            var ret = _.clone(this.toJSON());
             ret.attachments = _.clone(this.attributes.attachments.toJSON());
             return ret;
         },
@@ -138,17 +140,15 @@ define.async('io.ox/mail/compose/model', [
                 this._shadowAttributes = {};
             } else if (flag === false) {
                 this.updateShadow();
-            } else {
-                return !_.isEqual(this._shadowAttributes, this.getCopy());
             }
+            return !_.isEqual(this._shadowAttributes, this.getCopy());
         },
 
         getContentType: function () {
             if (this.get('editorMode') === 'text') {
                 return 'text/plain';
-            } else {
-                return this.get('editorMode') === 'html' ? 'text/html' : 'alternative';
             }
+            return this.get('editorMode') === 'html' ? 'text/html' : 'alternative';
         },
 
         setInitialMailContentType: function () {
@@ -193,6 +193,30 @@ define.async('io.ox/mail/compose/model', [
             return content;
         },
 
+        getSignatures: function () {
+            if (this.get('mode') === 'edit') {
+                this.set('defaultSignatureId', '', { silent: true });
+            }
+
+            if (_.device('!smartphone') || this.get('mode') === 'edit') return [];
+
+            if (settings.get('mobileSignatureType') === 'custom') {
+                this.set('defaultSignatureId', '0', { silent: true });
+            } else {
+                this.set('defaultSignatureId', '1', { silent: true });
+            }
+
+            var value = settings.get('mobileSignature');
+
+            if (value === undefined) {
+                value =
+                    //#. %s is the product name
+                    gt('Sent from %s via mobile', ox.serverConfig.productName);
+            }
+
+            return [{ id: '0', content: value, misc: { insertion: 'below' } }];
+        },
+
         parse: function (list) {
             return _(mailUtil.parseRecipients([].concat(list).join(', ')))
                 .map(function (recipient) {
