@@ -201,7 +201,11 @@ define('io.ox/mail/detail/content', [
         id: 'link-target',
         index: 500,
         process: function (baton) {
-            baton.source = baton.source.replace(/<a[^>]*href=(?:\"|\')(https?:\/\/[^>]+)(?:\"|\')[^>]*>/g, setLinkTarget);
+            baton.source = baton.source
+                // fix missing protocol
+                .replace(/(<a.*?href=("|'))www\./g, '$1http://www.')
+                // fix targets
+                .replace(/<a[^>]*href=(?:\"|\')(https?:\/\/[^>]+)(?:\"|\')[^>]*>/g, setLinkTarget);
         }
     });
 
@@ -235,7 +239,7 @@ define('io.ox/mail/detail/content', [
     function hasParent(elem, selector) {
         while (elem) {
             elem = elem.parentNode;
-            if (elem && elem.matches(selector)) return true;
+            if (elem && elem.matches && elem.matches(selector)) return true;
         }
         return false;
     }
@@ -311,7 +315,7 @@ define('io.ox/mail/detail/content', [
         process: function () {
             each(this, 'a', function (node) {
                 var link = $(node),
-                    href = link.attr('href') || '',
+                    href = link.attr('href') || '',
                     data, text;
                 // deep links?
                 if (links.isInternalDeepLink(href)) {
@@ -393,6 +397,17 @@ define('io.ox/mail/detail/content', [
         }
     });
 
+    ext.point('io.ox/mail/detail/content').extend({
+        id: 'check-simple',
+        index: 1100,
+        process: function () {
+            var container = $(this);
+            // if a mail contains a table, we assume that it is a mail with a lot of markup
+            // and styles and things like max-width: 100% will destroy the layout
+            if (container.find('table').length === 0) container.addClass('simple-mail');
+        }
+    });
+
     ext.point('io.ox/mail/detail/content').extend({
         id: 'form-submit',
         index: 1200,
@@ -409,6 +424,21 @@ define('io.ox/mail/detail/content', [
         }
     });
 
+    // commented out DUE TO BUGS! (27.01.2016)
+    // ext.point('io.ox/mail/detail/content').extend({
+    //     id: 'lazyload-images',
+    //     index: 1200,
+    //     process: function () {
+    //         $(this).find('img[src!=""]').each(function () {
+    //             var img = $(this);
+    //             img.attr({
+    //                 'data-original': img.attr('src'),
+    //                 'src': '//:0'
+    //             }).addClass('lazyload');
+    //         });
+    //     }
+    // });
+
     function isBlockquoteToggle(elem) {
         return $(elem).parent().hasClass('blockquote-toggle');
     }
@@ -464,14 +494,13 @@ define('io.ox/mail/detail/content', [
 
             try {
 
-                // find first text/html attachment to determine content type
+                // find first text/html attachment that is not displaytype attachment or none to determine content type
                 _(data.attachments).find(function (obj) {
-                    if ((/^text\/(plain|html)$/i).test(obj.content_type)) {
+                    if ((obj.disp !== 'attachment' && obj.disp !== 'none') && (/^text\/(plain|html)$/i).test(obj.content_type)) {
                         baton.type = obj.content_type;
                         return true;
-                    } else {
-                        return false;
                     }
+                    return false;
                 });
 
                 // add other parts?
@@ -496,16 +525,16 @@ define('io.ox/mail/detail/content', [
                 if (baton.isHTML) {
                     // robust constructor for large HTML -- no jQuery here to avoid its caches
                     content = document.createElement('DIV');
-                    content.className = 'content noI18n';
+                    content.className = 'mail-detail-content noI18n';
                     content.innerHTML = baton.source;
                     // last line of defense
                     each(content, 'script, base, meta', function (node) {
-                        node.parentNode.remove(node);
+                        node.parentNode.removeChild(node);
                     });
                 } else {
                     // plain TEXT
                     content = document.createElement('DIV');
-                    content.className = 'content plain-text noI18n';
+                    content.className = 'mail-detail-content plain-text noI18n';
                     content.innerHTML = beautifyText(baton.source);
                     if (!baton.processedEmoji) {
                         emoji.processEmoji(baton.source, function (text, lib) {
