@@ -190,23 +190,26 @@ define('io.ox/mail/mailfilter/settings/filter', [
             var createExtpointForSelectedFilter = function (node, args, config) {
                     ext.point('io.ox/settings/mailfilter/filter/settings/detail').invoke('draw', node, args, config);
                 },
-                self = this;
+                self = this,
+                scrollPane =  $node.closest('.scrollable-pane');
 
             return $.when(api.getRules(), api.getConfig()).then(function (data, config) {
-                var data = data[0],
-                    config = config[0];
+                data = data[0];
+                config = config[0];
 
                 collection = factory.createCollection(data);
                 collection.comparator = function (model) {
                     return model.get('position');
                 };
 
-                $node.closest('.scrollable-pane').on('refresh:mailfilter', function () {
+                scrollPane.one('refresh:mailfilter', function () {
                     self.refresh();
                 });
 
-                var FilterSettingsView = DisposableView.extend({
+                var FilterSettingsView,
+                    MailfilterEdit;
 
+                FilterSettingsView = DisposableView.extend({
                     tagName: 'li',
 
                     className: 'widget-settings-view',
@@ -234,7 +237,7 @@ define('io.ox/mail/mailfilter/settings/filter', [
                         }
 
                         function getEditableState() {
-                            return (checkForUnknown() === 'unknown' || _.contains(['autoforward', 'spam', 'vacation'], flag))  ? 'fixed' : 'editable';
+                            return (checkForUnknown() === 'unknown' || _.contains(['autoforward', 'spam', 'vacation'], flag)) ? 'fixed' : 'editable';
                         }
 
                         var title = self.model.get('rulename'),
@@ -243,8 +246,11 @@ define('io.ox/mail/mailfilter/settings/filter', [
                         this.$el.attr({
                             'data-id': self.model.get('id')
                         })
-                        .addClass('draggable ' + getEditableState() + ' ' + (self.model.get('active') ? 'active' : 'disabled'))
-                        .append(
+
+                        .addClass('draggable ' + getEditableState())
+                        .toggleClass('active', self.model.get('active'))
+                        .toggleClass('disabled', !self.model.get('active'))
+                        .empty().append(
 
                             listUtils.dragHandle(title, gt('Use cursor keys to change the item position. Virtual cursor mode has to be disabled.'), this.model.collection.length <= 1 ? 'hidden' : ''),
                             titleNode = listUtils.widgetTitle(title),
@@ -325,28 +331,39 @@ define('io.ox/mail/mailfilter/settings/filter', [
                         e.preventDefault();
                         var self = this,
                             id = self.model.get('id');
-                        if (id !== false) {
-                            //yell on reject
-                            settingsUtil.yellOnReject(
-                                api.deleteRule(id).done(function () {
-                                    var arrayOfFilters,
-                                        data;
-                                    self.model.collection.remove(id);
-                                    $node.find('.controls [data-action="add"]').focus();
 
-                                    arrayOfFilters = $node.find('li[data-id]');
-                                    data = _.map(arrayOfFilters, function (single) {
-                                        return parseInt($(single).attr('data-id'), 10);
-                                    });
+                        new dialogs.ModalDialog()
+                        .text(gt('Do you really want to delete this filter rule?'))
+                        .addPrimaryButton('delete', gt('Delete'), 'delete', { 'tabIndex': '1' })
+                        .addButton('cancel', gt('Cancel'), 'cancel', { 'tabIndex': '1' })
+                        .show()
+                        .done(function (action) {
+                            if (action === 'delete') {
+                                if (id !== false) {
                                     //yell on reject
+                                    self.model.collection.remove(id);
                                     settingsUtil.yellOnReject(
-                                        api.reorder(data)
+                                        api.deleteRule(id).done(function () {
+                                            var arrayOfFilters,
+                                                data;
+                                            $node.find('.controls [data-action="add"]').focus();
+
+                                            arrayOfFilters = $node.find('li[data-id]');
+                                            data = _.map(arrayOfFilters, function (single) {
+                                                return parseInt($(single).attr('data-id'), 10);
+                                            });
+                                            //yell on reject
+                                            settingsUtil.yellOnReject(
+                                                api.reorder(data)
+                                            );
+                                            updatePositionInCollection(collection, data);
+
+                                        })
                                     );
-                                    updatePositionInCollection(collection, data);
+                                }
+                            }
+                        });
 
-                                })
-                            );
-                        }
                     },
 
                     onEdit: function (e) {
@@ -402,21 +419,17 @@ define('io.ox/mail/mailfilter/settings/filter', [
                         }
 
                         switch (e.which) {
-                        case 38:
-                            if (index > 0) {
-                                keyHandle('up');
-                            }
-                            break;
-                        case 40:
-                            if (index < items.length) {
-                                keyHandle('down');
-                            }
-                            break;
-                        default:
-                            break;
+                            case 38:
+                                if (index > 0) keyHandle('up');
+                                break;
+                            case 40:
+                                if (index < items.length) keyHandle('down');
+                                break;
+                            default:
+                                break;
                         }
                     }
-                }),
+                });
 
                 MailfilterEdit = Backbone.View.extend({
 
@@ -483,9 +496,9 @@ define('io.ox/mail/mailfilter/settings/filter', [
                             stop: function (e, ui) {
                                 ui.item.attr('aria-grabbed', 'false');
                                 var arrayOfFilters = $node.find('li[data-id]'),
-                                data = _.map(arrayOfFilters, function (single) {
-                                    return parseInt($(single).attr('data-id'), 10);
-                                });
+                                    data = _.map(arrayOfFilters, function (single) {
+                                        return parseInt($(single).attr('data-id'), 10);
+                                    });
 
                                 //yell on reject
                                 settingsUtil.yellOnReject(
@@ -496,9 +509,10 @@ define('io.ox/mail/mailfilter/settings/filter', [
                         });
                     }
 
-                }),
+                });
+
+                var mailFilter = new MailfilterEdit();
 
-                mailFilter = new MailfilterEdit();
                 $node.append(mailFilter.render().$el);
                 return collection;
             });
@@ -522,7 +536,6 @@ define('io.ox/mail/mailfilter/settings/filter', [
             });
 
         }
-
     };
 
 });
