@@ -42,8 +42,8 @@ define('io.ox/mail/settings/defaults', [], function () {
         //for persistent sort
         'sort': 'thread',
         'order': 'desc',
-        'unread': false
-
+        'unread': false,
+        'simpleLineBreaks': true
     };
 
     return settingsDefaults;
