@@ -18,9 +18,10 @@ define.async('io.ox/realtime/polling_transport',
         'io.ox/core/uuids',
         'io.ox/core/http',
         'io.ox/realtime/stanza',
-        'io.ox/realtime/tab_id'
+        'io.ox/realtime/tab_id',
+        'io.ox/realtime/synchronized_http'
     ],
-function (ext, Event, caps, uuids, http, stanza, tabId) {
+function (ext, Event, caps, uuids, http, stanza, tabId, synchronizedHTTP) {
 
     'use strict';
 
@@ -49,7 +50,6 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
     var ackBuffer = {};
 
     var rejectAll = false;
-    var transmitting = false;
     var purging = false;
     var enroled = false;
     var traceAll = false;
@@ -130,16 +130,6 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
         if (api.trace) {
             console.log('Drain buffer');
         }
-        if (transmitting) {
-            if (api.trace) {
-                console.log('Transmitting so skipping purge');
-            }
-            if (api.trace) {
-                console.log('Aborting purge, transmission in progress so setting purging to false');
-            }
-
-            return;
-        }
         if (!enroled) {
             return;
         }
@@ -170,8 +160,7 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
             console.log('Starting purge, so setting purging to true');
         }
 
-        transmitting = true;
-        http.PUT({
+        synchronizedHTTP.PUT({
             module: 'rt',
             params: {
                 action: 'send',
@@ -180,9 +169,9 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
             data: stanzas,
             noRetry: true,
             timeout: TIMEOUT,
-            silent: true
+            silent: true,
+            skipable: true
         }).done(function (resp) {
-            transmitting = false;
             purging = false;
             if (api.trace) {
                 console.log('Purged stanzas, so setting purging to false');
@@ -192,7 +181,6 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
                 purge();
             }
         }).fail(function (resp) {
-            transmitting = false;
             purging = false;
             if (api.debug) {
                 console.log('Purging call failed, setting purging to false', resp);
@@ -237,24 +225,24 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
     // Periodically poll
     actions.poll = function () {
         // no need to poll if no one is listening for events
-        if (! someoneIsListeningForRemoveEvents()) {
+        if (!someoneIsListeningForRemoveEvents()) {
             return;
         }
 
         var lastFetchInterval = _.now() - lastCheck;
         var interval = _.now() - lastDelivery;
-        if (lastFetchInterval >= intervals[mode] && !purging && !transmitting) {
+        if (lastFetchInterval >= intervals[mode] && !purging) {
             lastCheck = _.now();
-            transmitting = true;
 
-            http.GET({
+            synchronizedHTTP.GET({
                 module: 'rt',
                 params: {
                     action: 'poll',
                     resource: tabId
                 },
                 timeout: TIMEOUT,
-                silent: true
+                silent: true,
+                skipable: true
             }).done(handleResponse).fail(handleError);
         }
 
@@ -312,7 +300,6 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
         delete resendBuffer[sequenceNumber];
         if (resendDeferreds[sequenceNumber]) {
             resendDeferreds[sequenceNumber].resolve();
-        } else {
         }
         if (api.debug) {
             console.log('Received receipt for ' + sequenceNumber);
@@ -339,7 +326,7 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
             console.log('Resetting sequence to ', newSequence);
         }
         flushAllBuffers();
-        http.PUT({
+        synchronizedHTTP.PUT({
             module: 'rt',
             params: {
                 action: 'send',
@@ -458,19 +445,13 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
                     }
                     resetSequence(0);
                 }
-            } else {
-                if (api.debug) {
-                    console.log('Already received ' + stanza.seq + '. Waiting for ' + (serverSequenceThreshhold + 1));
-                }
+            } else if (api.debug) {
+                console.log('Already received ' + stanza.seq + '. Waiting for ' + (serverSequenceThreshhold + 1));
             }
         }
     }
 
     function handleError(error) {
-        transmitting = false;
-        if (api.debug) {
-            console.log('handleError: setting transmitting to false');
-        }
 
         if (error.code === 'RT_STANZA-1006' || error.code === 'RT_STANZA-0006' || error.code === 1006 || error.code === 6) {
             if (api.debug) {
@@ -491,10 +472,6 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
     }
 
     function handleResponse(resp) {
-        transmitting = false;
-        if (api.debug) {
-            console.log('handleResponse: setting transmitting to false');
-        }
         damage.reset();
 
         var result = null;
@@ -529,7 +506,7 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
             return $.when();
         }
         if (!enroled) {
-            return http.GET({
+            return synchronizedHTTP.GET({
                 module: 'rt',
                 params: {
                     action: 'enrol',
@@ -612,52 +589,50 @@ function (ext, Event, caps, uuids, http, stanza, tabId) {
 
     api.query = function (options) {
         var def = $.Deferred();
+        var previousOperation = null;
         if (options.trace || traceAll) {
             delete options.trace;
             options.tracer = ox.user + '@' + ox.context_id + ' [' + uuids.randomUUID() + ']';
         }
         options.seq = seq;
         seq++;
-        transmitting = true;
-        if (api.debug) {
-            console.log('Transmitting query, so setting transmitting to true');
-        }
+        previousOperation = resendDeferreds[Number(options.seq - 1)] || $.when();
+        // Wait for an ACK for the previous operation, so the stanza gates
+        // don't get mixed up
 
-        http.PUT({
-            module: 'rt',
-            params: {
-                action: 'query',
-                resource: tabId
-            },
-            timeout: TIMEOUT,
-            data: options,
-            silent: true
-        }).done(function (resp) {
-            transmitting = false;
-            if (api.debug) {
-                console.log('Query completed, setting transmitting to false');
-            }
-            var stanzas = resp.stanzas;
-            resp.stanzas = [];
-            // Handle the regular stanzas later
-            setTimeout(function () {
-                handleResponse({ stanzas: stanzas });
-            }, 0);
-            if (resp.error) {
-                handleError(resp.error);
+        previousOperation.done(function () {
+            synchronizedHTTP.PUT({
+                module: 'rt',
+                params: {
+                    action: 'query',
+                    resource: tabId
+                },
+                timeout: TIMEOUT,
+                data: options,
+                silent: true
+            }).done(function (resp) {
+                var stanzas = resp.stanzas;
+                resp.stanzas = [];
+                // Handle the regular stanzas later
+                setTimeout(function () {
+                    handleResponse({ stanzas: stanzas });
+                }, 0);
+                if (resp.error) {
+                    handleError(resp.error);
+                    def.reject(resp);
+                } else {
+                    def.resolve(handleResponse(resp));
+                }
+            }).fail(function (resp) {
+                handleError(resp);
+                // Send a dummy message to consume the sequence number
+                api.send({
+                    to: 'devnull://sequenceDiscard',
+                    seq: options.seq,
+                    element: 'message'
+                });
                 def.reject(resp);
-            } else {
-                def.resolve(handleResponse(resp));
-            }
-        }).fail(function (resp) {
-            handleError(resp);
-            // Send a dummy message to consume the sequence number
-            api.send({
-                to: 'devnull://sequenceDiscard',
-                seq: options.seq,
-                element: 'message'
             });
-            def.reject(resp);
         });
 
         return def;
