@@ -11,10 +11,10 @@
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 
-define('plugins/halo/test',
-    ['io.ox/core/extensions',
-     'plugins/halo/config'
-    ], function (ext, haloConfig) {
+define('plugins/halo/test', [
+    'io.ox/core/extensions',
+    'plugins/halo/config'
+], function (ext, haloConfig) {
 
     'use strict';
 
