@@ -21,7 +21,7 @@ define(['io.ox/core/api/autocomplete'], function (api) {
                 it('should define a search method', function () {
                     expect(instance.search).to.be.a('function');
                 });
-                it('should define a processContactItem method', function () {
+                it.skip('should define a processContactItem method', function () {
                     expect(instance.processContactItem).to.be.a('function');
                 });
                 it('should define a processContactResults method', function () {
