@@ -13,22 +13,62 @@
 define(['io.ox/mail/compose/main', 'settings!io.ox/mail'], function (compose, settings) {
     'use strict';
 
+    var editors = {
+        text: 'io.ox/core/tk/text-editor',
+        html: 'io.ox/core/tk/contenteditable-editor'
+    };
+
     describe('Mail Compose', function () {
-        var app;
-        beforeEach(function () {
-            this.server.respondWith('GET', /api\/halo\/contact\/picture/, function (xhr) {
-                xhr.respond(200, 'image/gif', '');
-            });
-            app = compose.getApp();
-            return app.launch();
-        });
-        afterEach(function () {
-            if (app.view && app.view.model) {
-                app.view.model.dirty(false);
-            }
-            return app.quit();
-        });
+
         describe('forward a message', function () {
+
+            var app, pictureHalo, snippetsGetAll, getValidAddress;
+
+            var editors = {
+                    text: 'io.ox/core/tk/text-editor',
+                    html: 'io.ox/core/tk/contenteditable-editor'
+                },
+                pluginStub;
+
+            beforeEach(function () {
+                pluginStub = sinon.stub(ox.manifests, 'loadPluginsFor', function (namespace) {
+                    namespace = namespace.replace(/^io.ox\/mail\/compose\/editor\//, '');
+                    return require([editors[namespace]]);
+                });
+            });
+
+            afterEach(function () {
+                pluginStub.restore();
+            });
+
+            beforeEach(function () {
+                return require([
+                    'io.ox/core/api/snippets',
+                    'io.ox/contacts/api',
+                    'io.ox/core/api/account',
+                    'settings!io.ox/mail'
+                ], function (snippetAPI, contactsAPI, accountAPI, settings) {
+                    snippetsGetAll = sinon.stub(snippetAPI, 'getAll', function () { return $.when([]); });
+                    pictureHalo = sinon.stub(contactsAPI, 'pictureHalo', _.noop);
+                    getValidAddress = sinon.stub(accountAPI, 'getValidAddress', function (d) { return $.when(d); });
+                    //load plaintext editor, much faster than spinning up tinymce all the time
+                    settings.set('messageFormat', 'text');
+                }).then(function () {
+                    app = compose.getApp();
+                    return app.launch();
+                });
+            });
+
+            afterEach(function () {
+                if (app.view && app.view.model) {
+                    app.view.model.dirty(false);
+                }
+                snippetsGetAll.restore();
+                pictureHalo.restore();
+                getValidAddress.restore();
+                return app.quit();
+            });
+
             beforeEach(function () {
                 this.server.respondWith('PUT', /api\/mail\?action=forward/, function (xhr) {
                     xhr.respond(200, { 'Content-Type': 'text/javascript;charset=UTF-8' }, JSON.stringify({
@@ -69,6 +109,8 @@ define(['io.ox/mail/compose/main', 'settings!io.ox/mail'], function (compose, se
                     var mail = spy.firstCall.args[0];
                     expect(mail.sendtype).to.equal(api.SENDTYPE.FORWARD);
                     expect(mail.msgref).to.equal('default0/INBOX/666');
+                    expect(mail.flags & api.FLAGS.DRAFT, 'DRAFT flag not set').to.equal(0);
+
                     spy.restore();
                 });
             });
@@ -77,9 +119,6 @@ define(['io.ox/mail/compose/main', 'settings!io.ox/mail'], function (compose, se
                 settings.set('autoSaveDraftsAfter', '1_minute');
                 var callback = sinon.spy();
                 var api = require('io.ox/mail/api');
-                //don't fetch contact pictures
-                var contactAPI = require('io.ox/contacts/api');
-                var haloSpy = sinon.stub(contactAPI, 'pictureHalo', _.noop);
 
                 expect(app.view.model.get('sendtype')).to.equal(api.SENDTYPE.FORWARD);
                 expect(app.view.model.get('msgref')).to.exist;
@@ -99,18 +138,27 @@ define(['io.ox/mail/compose/main', 'settings!io.ox/mail'], function (compose, se
                 app.view.model.set('to', [['Test', 'test@example.com']]);
                 clock.tick(59999);
                 expect(callback.called, 'callback called').to.be.false;
+                // touch the model
+                app.model.dirty(true);
                 //takes a little while for the request to be sent
                 clock.tick(100);
                 expect(callback.calledOnce, 'callback called').to.be.true;
+                // send type and msgref stay intact, but draft flag is set
                 var mail = JSON.parse(callback.firstCall.args[0]);
-                expect(mail.sendtype).to.equal(api.SENDTYPE.EDIT_DRAFT);
-                expect(mail.msgref).not.to.exist;
+                expect(mail.sendtype).to.equal(api.SENDTYPE.FORWARD);
+                expect(mail.msgref).to.exist;
+                expect(mail.msgref).to.equal('default0/INBOX/666');
+                expect(mail.flags & api.FLAGS.DRAFT, 'DRAFT flag set').to.equal(api.FLAGS.DRAFT);
 
+                // touch the model
+                app.model.dirty(true);
                 clock.tick(60000);
                 expect(callback.calledTwice, 'callback called').to.be.true;
                 mail = JSON.parse(callback.secondCall.args[0]);
+                // now in edit draft mode
                 expect(mail.sendtype).to.equal(api.SENDTYPE.EDIT_DRAFT);
                 expect(mail.msgref).to.equal('default0/INBOX/Drafts/666');
+                expect(mail.flags & api.FLAGS.DRAFT, 'DRAFT flag set').to.equal(api.FLAGS.DRAFT);
 
                 clock.restore();
 
@@ -126,8 +174,9 @@ define(['io.ox/mail/compose/main', 'settings!io.ox/mail'], function (compose, se
                     var mail = spy.firstCall.args[0];
                     expect(mail.sendtype).to.equal(api.SENDTYPE.DRAFT);
                     expect(mail.msgref).to.equal('default0/INBOX/Drafts/666');
+                    expect(mail.flags & api.FLAGS.DRAFT, 'DRAFT flag not set').to.equal(0);
+
                     spy.restore();
-                    haloSpy.restore();
                     settings.set('autoSaveDraftsAfter', 'disabled');
                 });
             });
