@@ -15,9 +15,7 @@ define(['io.ox/mail/threadview', 'io.ox/mail/api', 'fixture!io.ox/mail/thread.js
 
     'use strict';
 
-    var expect = chai.expect;
-
-    describe('The Threadview.', function () {
+    describe('Mail Threadview', function () {
 
         beforeEach(function () {
             this.view = new threadview.Desktop();
