@@ -16,15 +16,15 @@ define(['io.ox/portal/util', 'settings!io.ox/portal'], function (util, settings)
         var expect = chai.expect;
         describe('getWidgets function', function () {
             it('should always return an array', function () {
-                expect(util.getWidgets(undefined)).to.be.an('array');
+                expect(util.getWidgets()).to.be.an('array');
             });
-            it('should return an array of specific length depending on current settings value', function () {
-                //this test used to fail because of some race condition. if this still fails,
-                //make this async? seems to work fine, at the moment
-                var widgets = settings.get('widgets/user', {}),
-                    length = widgets.length || 0,
-                    result = util.getWidgets(undefined).length;
-                expect(result).to.equal(length);
+            it('should return an array of widgets stored in the settings', function () {
+                settings.set('widgets/user');
+                expect(util.getWidgets().length).to.equal(0);
+                settings.set('widgets/user', {
+                    dummyWidget: { props: {} }
+                }),
+                expect(util.getWidgets().length).to.equal(1);
             });
         });
         describe('getWidgetsByType function', function () {
@@ -32,6 +32,7 @@ define(['io.ox/portal/util', 'settings!io.ox/portal'], function (util, settings)
                 expect(util.getWidgetsByType(undefined)).to.be.an('array');
             });
             it('should return an empty array if type is not used in portal', function () {
+                settings.set('widgets/user');
                 expect(util.getWidgetsByType(undefined)).to.be.empty;
                 expect(util.getWidgetsByType('notExistingType')).to.be.empty;
             });
