@@ -173,7 +173,7 @@
          */
         hash: (function () {
 
-            var key;
+            var key, invalidKey = false;
 
             // this is not cryptography!
             // it just makes certain parameters like "folder" unreadable
@@ -204,8 +204,11 @@
             }
 
             key = _.getCookie('url.key');
-            // replace by new key if invalid
-            if (!/^\d+$/.test(key)) _.setCookie('url.key', key = getKey());
+            // replace by new key if invalid (expires never; let's say in 10 years)
+            if (!/^\d+$/.test(key)) {
+                invalidKey = true;
+                _.setCookie('url.key', key = getKey(), 1000 * 3600 * 24 * 365 * 10);
+            }
             // transform to integers
             key = key.split('').map(function (i) { return parseInt(i, 10); });
 
@@ -217,14 +220,11 @@
                 if (arguments.length === 0) {
                     return url.data;
                 } else if (arguments.length === 1) {
-                    if (_.isString(name)) {
-                        return url.data[name];
-                    } else {
-                        _(name).each(function (value, name) {
-                            url.set(name, value);
-                        });
-                        url.update();
-                    }
+                    if (_.isString(name)) return url.data[name];
+                    _(name).each(function (value, name) {
+                        url.set(name, value);
+                    });
+                    url.update();
                 } else if (arguments.length === 2) {
                     url.set(name, value);
                     url.update();
@@ -243,6 +243,9 @@
 
             url.encrypt = function (data) {
                 var obj = _.extend({}, data);
+                // do not change 99% case
+                if (/^default\d+\/inbox$/i.test(data.folder)) return obj;
+                // encrypt all other mail folders
                 if (/^default\d+\//.test(data.folder)) {
                     var index = data.folder.indexOf('/') + 1;
                     obj.folder = data.folder.substr(0, index) + '/' + encrypt(data.folder.substr(index));
@@ -286,6 +289,9 @@
             decode();
             $(window).on('hashchange', decode);
 
+            // remove invlid folder
+            if (invalidKey && /^default\d+\//.test(url.data.folder)) url.set('folder', null);
+
             return url;
 
         }()),
@@ -294,7 +300,22 @@
          * Redirect
          */
         redirect: function (path) {
-            location.href = (/^http/i).test(path) ? path : _.url.get(path);
+
+            var current = location.pathname;
+
+            if ((/^http/i).test(path)) {
+                location.href = path;
+                return;
+            }
+
+            // clear hash first
+            location.hash = '#';
+            location.replace(_.url.get(path));
+
+            // enforce page reload if path is still the same
+            _.defer(function () {
+                if (location.pathname === current) location.reload(true);
+            });
         },
 
         get: function (path) {
@@ -421,6 +442,11 @@
             return _.copy(elem, true);
         },
 
+        // until es6 default parameters
+        defaultValue: function (value, defaultvalue) {
+            return _.isUndefined(value) ? defaultvalue : value;
+        },
+
         /**
          * Lastest function only
          * Works with non-anonymous functions only
@@ -450,12 +476,15 @@
          */
         queued: function (fn, timeout) {
 
-            var hash = {};
+            var hash = {}, guid = 0;
 
             return function () {
 
+                // add guid
+                fn.queue_guid = fn.queue_guid || guid++;
+
                 var def = $.Deferred(),
-                    queue = hash[fn] || (hash[fn] = [$.when()]),
+                    queue = hash[fn.queue_guid] || (hash[fn.queue_guid] = [$.when()]),
                     last = _(queue).last(),
                     self = this,
                     args = $.makeArray(arguments);
@@ -562,10 +591,10 @@
         filesize: function (size, options) {
 
             var opt = _.extend({
-                    digits: 0,
-                    force: true,
-                    zerochar: undefined
-                }, options || {});
+                digits: 0,
+                force: true,
+                zerochar: undefined
+            }, options || {});
 
             //for security so math.pow doesn't get really high values
             if (opt.digits > 10) {
@@ -578,8 +607,8 @@
             }
             val = (Math.round(size * dp, 1) / dp);
             //replacement to 0
-            if (typeof opt.zerochar !== 'undefined' && val === 0)
-                return opt.zerochar;
+            if (typeof opt.zerochar !== 'undefined' && val === 0) return opt.zerochar;
+
             return (opt.force ? val : val.toFixed(opt.digits)) + '\xA0' + sizes[i];
         },
 
@@ -594,6 +623,7 @@
          * @return {string}
          */
         ellipsis: function (str, options) {
+            /* eslint dot-notation: [2, {"allowKeywords": true}] */
             //be robust
             str = String(str || '').trim();
             var opt = _.extend({
@@ -607,14 +637,13 @@
                 return str;
             } else if (opt.charpos === 'end') {
                 return str.substr(0, opt.max - opt.char.length) + opt.char;
-            } else {
-                //fix invalid length
-                if (!opt.length || opt.length * 2 > space) {
-                    //save space for ellipse char
-                    opt.length = (space % 2 === 0 ? space  / 2 : (opt.max / 2) - 1) || 1;
-                }
-                return str.substr(0, opt.length).trim() + opt.char + str.substr(str.length - opt.length).trim();
             }
+            //fix invalid length
+            if (!opt.length || opt.length * 2 > space) {
+                //save space for ellipse char
+                opt.length = (space % 2 === 0 ? space / 2 : (opt.max / 2) - 1) || 1;
+            }
+            return str.substr(0, opt.length).trim() + opt.char + str.substr(str.length - opt.length).trim();
         },
 
         /**
@@ -697,9 +726,8 @@
                 if (remaining <= 0) {
                     previous = now;
                     result = func.apply(context, args);
-                } else {
-                    timeout = setTimeout(later, remaining);
                 }
+                timeout = setTimeout(later, remaining);
                 return result;
             };
         },
@@ -731,21 +759,33 @@
         cid: (function () {
 
             function encode(s) {
-                return String(s).replace(/\./g, '\\.');
+                // escape dots and backslashes
+                return String(s).replace(/([.\\])/g, '\\$1');
             }
 
             function decode(s) {
-                // find first unescaped dot
+                var regex = /(\\\\|\\\.|\.)/g, match, parts = ['', ''], index = 0, p = 0;
+                // ensure we have a string
                 s = String(s);
-                var pos = s.search(/([^\\])\./);
-                if (pos === -1) {
-                    return { id: s };
-                } else {
-                    return {
-                        folder_id: s.substr(0, pos + 1).replace(/\\(\\?)/g, '$1'),
-                        id: s.substr(pos + 2).replace(/\\(\\?)/g, '$1')
-                    };
+                // process string step by step in a loop
+                while ((match = regex.exec(s)) !== null) {
+                    // append substring before the match (use substring; not substr!)
+                    parts[p] += s.substring(index, match.index);
+                    // now handle match
+                    switch (match[0]) {
+                        // escaped backslash
+                        case '\\\\': parts[p] += '\\'; break;
+                        // escaped dot
+                        case '\\.': parts[p] += '.'; break;
+                        // dot
+                        case '.': p = 1; break;
+                        // no default
+                    }
+                    index = match.index + match[0].length;
                 }
+                // add tail (with just 1 parameter substring and substr are identical)
+                parts[p] += s.substring(index);
+                return p === 0 ? { id: parts[0] } : { folder_id: parts[0], id: parts[1] };
             }
 
             return function (o) {
@@ -766,8 +806,8 @@
                     if (o[r] !== undefined && o[r] !== null) {
                         // if we have a recurrence position we need a folder
                         tmp = encode(f || 0) + '.' + tmp + '.' + encode(o[r]);
-                    } else {
-                        if (f !== undefined) { tmp = encode(f) + '.' + tmp; }
+                    } else if (f !== undefined) {
+                        tmp = encode(f) + '.' + tmp;
                     }
                     return tmp;
                 }
@@ -792,8 +832,7 @@
         toHash: function (array, prop) {
             var tmp = {};
             _(array).each(function (obj) {
-                if (obj && prop && _.isString(prop))
-                    tmp[obj[prop]] = obj;
+                if (obj && prop && _.isString(prop)) tmp[obj[prop]] = obj;
             });
             return tmp;
         },
@@ -829,11 +868,11 @@
      * @return The unescaped string with resolved entities.
      */
     _.unescapeHTML = function (html) {
+        /*eslint no-nested-ternary: 0*/
         return (html || '').replace(/&(?:(\w+)|#x([0-9A-Fa-f]+)|#(\d+));/g,
                             function (original, entity, hex, dec) {
                                 return entity ? _.unescapeHTML.entities[entity] || original :
-                                       hex    ? String.fromCharCode(parseInt(hex, 16)) :
-                                                String.fromCharCode(parseInt(dec, 10));
+                                       hex ? String.fromCharCode(parseInt(hex, 16)) : String.fromCharCode(parseInt(dec, 10));
                             });
     };
 
